{% extends "scope.editobject.generic.tpl" %}

{% block block_customFunctions %}
{{ parent() }}

{# This function returns steps array for maximum selection #}
this.getMaxSteps = function()
{
    var steps = {};
    for(var i=1; i <= 6; i++)    steps[i] = i;
    return steps;
}

{# This function returns steps array limited by maximum step #}
this.getLoadSteps = function(objId)
{
    var maxStep = objM.getObj(this.id).options.max_step;
    var steps = {"":"---"};

    {# If no priority sub-object is present, skipping #}
    var priorityId = objM.object_get_id_by_complexobject_tag(objId,"load_priority");
    if(priorityId==-1)  return steps;

    for(var i=1; i <= maxStep; i++)    steps[i] = i;
    return steps;
}

{# This function returns step number by given load object ID #}
this.getLoadStep = function(objId)
{
    var priorityId = objM.object_get_id_by_complexobject_tag(objId,"load_priority");
    if(priorityId==-1)  return -1;
    
    var priorityObj = objM.getObj(priorityId);
    return priorityObj.current_value;
}

{# This function updates step for given load #}
this.updateLoadStep = function(objId,step)
{
    var priorityId = objM.object_get_id_by_complexobject_tag(objId,"load_priority");
    if(priorityId==-1)  return;

    objM.updateFieldObj(priorityId,"current_value",step);
}

{# This function checks if object has all necessary sub-objects #}
this.objCheck = function(objId,role,outputType)
{
    if(typeof(outputType)=="undefined") outputType="message";
    
    switch(role)
    {
        case "meter":
        
            {# Meter needs at least one power or current+voltage #}
            if(objM.object_get_id_by_complexobject_tag(objId,"power_value")==-1)
            {
                if(objM.object_get_id_by_complexobject_tag(objId,"current_value")==-1 || objM.object_get_id_by_complexobject_tag(objId,"voltage_value")==-1)
                    return this.objCheckGetMissingByTag("power_value",outputType,"compulsory");
                else
                {
                    if(objM.object_get_id_by_complexobject_tag(objId,"current_value")==-1)
                    {
                        return this.objCheckGetMissingByTag("current_value",outputType,"compulsory");
                    }
                    if(objM.object_get_id_by_complexobject_tag(objId,"voltage_value")==-1)
                    {
                        return this.objCheckGetMissingByTag("voltage_value",outputType,"compulsory");
                    }
                }
            }

            {# Meter needs thresholds #}
            if(objM.object_get_id_by_complexobject_tag(objId,"power_threshold_1")==-1)
            {
                {# Checking if threshold is set as meter optional parameter #}
                var threshold = objM.getObj(objId).options["power_threshold_1"];
                if(!threshold || threshold==0 || threshold == '')
                {
                    return this.objCheckGetMissingByTag("power_threshold_1",outputType,"compulsory");
                }
            }
            if(objM.object_get_id_by_complexobject_tag(objId,"power_threshold_2")==-1)
            {
                {# Checking if threshold is set as meter optional parameter #}
                var threshold = objM.getObj(objId).options["power_threshold_2"];
                if(!threshold || threshold==0 || threshold == '')
                {
                    return this.objCheckGetMissingByTag("power_threshold_2",outputType,"compulsory");
                }
            }
        
            {# Meter needs priority #}
            if(objM.object_get_id_by_complexobject_tag(objId,"load_priority")==-1)
            {
                return this.objCheckGetMissingByTag("load_priority",outputType,"compulsory");
            }

            {# Meter suggests threshold alarm #}
            if(objM.object_get_id_by_complexobject_tag(objId,"load_threshold_alarm")==-1)
            {
                return this.objCheckGetMissingByTag("load_threshold_alarm",outputType,"suggested");
            }

            break;
            
        case "load":
        
            {# Meter needs priority #}
            if(objM.object_get_id_by_complexobject_tag(objId,"load_priority")==-1)
            {
                {# Checking if priority is set as meter optional parameter #}
                var priority = objM.getObj(objId).options["load_priority"];
                if(!priority || priority == '')
                {
                    return this.objCheckGetMissingByTag("load_priority",outputType,"compulsory");
                }
            }
            
            {# Meter needs ON/OFF #}
            if(objM.object_get_id_by_complexobject_tag(objId,"load_on_off")==-1)
            {
                return this.objCheckGetMissingByTag("load_on_off",outputType,"compulsory");
            }
            
            {# Meter suggests auto/man #}
            if(objM.object_get_id_by_complexobject_tag(objId,"load_auto_man")==-1)
            {
                return this.objCheckGetMissingByTag("load_auto_man",outputType,"suggested");
            }
    }
    
    return this.objCheckGetOk(outputType);
}

this.objCheckGetMissingByTag = function(tag,outputType,severity)
{
    switch(outputType)
    {
        case "icon":
            switch(severity)
            {
                case "suggested":
                    return "IconWARN.png";
                    break;
                case "compulsory":
                    return "IconERR.png";
                    break;
            }
            break;
        case "message":
        default:
            return $.sprintf("{{getConstant('_DPAD_THEME_ADMIN_EDITOBJECT_LOADCONTROL_RELATIONS_CHECK_MISSING_SUBOBJECT')}}",rM.getConstant("_DPAD_DBCONSTANT_RENDERING_ENERGY_RELATION_BATTERY_" + tag.toUpperCase()));
            break;
    }
}

this.objCheckGetOk = function(outputType)
{
    switch(outputType)
    {
        case "icon":
            return "IconOK.png";
            break;
        case "message":
        default:
            return "{{getConstant('_DPAD_THEME_ADMIN_EDITOBJECT_LOADCONTROL_RELATIONS_CHECK_OK')}}";
            break;
    }
}

{# This script starts or stops script runner execution #}
this.scriptStopStart = function(action)
{
    objM.getObj(this.id).callSoap("",action);
}

{% endblock %}
