{% extends "scope.administration_page.tpl" %}

{% block block_includeJs %}
    {{ parent() }}
    {{ html_includejs("jsDpadBlock.js","js") }}
    {{ html_includejs("jquery.ui.sortable.js","js") }}
    {{ html_includejs("jquery.scrollTo.js","js") }}
{% endblock %}

{% block block_customDeclarations %}
        
        this.logData = new Array();
        this.offset = 0;                        //Default data offset
        this.limit = 100;                       //Default maximum number of items retrieved at once
        this.limitForExport = 25000;            //Default maximum number of items exported
        this.pageCurr = 1;                      //Current page in case of multiple pages
        this.pageTot = 1;                       //Number of pages in case of multiple pages
        this.lastReceivedLogId = 0;            //Last received log item ID from server
        this.lastRequestedLogId = '';           //Last requested log item ID to server
        
        this.realtimeMode = false;              //If set to true, real-time mode is activated, and log is periodically reloaded
        this.realtimeTimer = 2;                 //Number of seconds for automatic refresh
        this.realtimeHandler = null;            //Handler of timeout for real-time mode
        
        {{ jsBlock({
		'operation':"declaration",
		'block_name':"block_eiblog",
		'block_render_container_selector':"this.getScopeSelector()+' #eiblog_container'",
		'prototype_container':"$(this.getScopeSelector()).find('#block_eiblog_container_prototype').html();",
		'prototype_header':"$(this.getScopeSelector()).find('#block_eiblog_header_prototype > tbody').html();",
		'prototype_item':"$(this.getScopeSelector()).find('#block_eiblog_item_prototype > tbody').html();"
	}) }}
{% endblock %}

{% block block_onLoad_pageInit %}{% endblock %}
{% block block_onLoad %}

        if(!this.isInitialized)
        {
                {# Init Masks#}
                $(this.getScopeSelector()).find('input[mask]').each(function(){
                        $(this).mask($(this).attr('mask'));
                });
        }

        {# Initializing help #}
        this.initHelp();
        
	{# Showing/hiding elements depending on currently expert mode #}
	wM.expertModeToggle(wM.expertMode,true);

        {# Loading log #}
        this.logRefresh();

{% endblock %}

{% block block_onUnload %}
{% endblock block_onUnload %}

{% block block_formValidate %}{% endblock %}
{% block block_formButtonSubmit %}{% endblock %}
{% block block_formButtonSubmitCompleted %}{% endblock %}
{% block block_formSubmitCallback %}{% endblock %}

{% block block_formButtonClose %}
{# If workspace manager is not enabled, skipping #}
if(!wM.enabled && skipEnableCheck != true)  return;
{{ parent() }}
{# Closing tab corresponding to current page #}
wM.tabRemove(this.getTab());
{% endblock %}

{% block block_customFunctions %}
{% include "include.workspace_page_functions.tpl" %}

    {# This function loads log #}
    this.logLoad = function(){

        {# Identifying and passing filters to log load ajax function #}
        var srcaddr = $(this.getScopeSelector()).find("input#srcaddr").val();
        var dstaddr = $(this.getScopeSelector()).find("input#dstaddr").val();
        var payload = $(this.getScopeSelector()).find("input#payload").val();
        var date_from = $(this.getScopeSelector()).find("#date_from").val();
        var date_to = $(this.getScopeSelector()).find("#date_to").val();

        themeManager.waitplease_display(true);
        
        {# Performing AJAX call retrieving data #}
        rM.ajax({
            type: 'GET',
            url: '../eibdatalog/eiblog_getdata.php',
            dataType:'json',
            data: {
                    srcaddr:srcaddr,
                    dstaddr:dstaddr,
                    payload:payload,
                    date_from: (this.realtimeMode==true ? '' : date_from),
                    date_to: (this.realtimeMode==true ? '' : date_to),
                    offset:this.offset,
                    limit:this.limit,
                    last_log_id:this.lastRequestedLogId,
                    language:rM.getConfiguration("current_language",{refresh:false})
            },
            success:$.proxy(this.logLoadCallback,this)
        });
        
    }
    this.logLoadCallback = function(response){

        {# Handling result #}
        if(parseInt(response.result)!={{getConstant("_DPAD_RESULT_NOERROR")}})
        {
            var message = response.message ? response.message : "{{getConstant('_DPAD_DBCONSTANT_EIBDATALOG_VIEW_MESSAGE_ERROR_LOADING_LOG')|encode4jscript}}";
            this.messageId = this.updateMessage(this.messageId,message,"warn",10);
            return;
        }

        {# Updating paging #}
        this.pageTot = Math.max(1,Math.ceil(parseInt(response.log.counter)/this.limit));
        this.pageCurr = Math.ceil((this.offset+1)/this.limit);
        this.pagerUpdate();
        
        {# Updating total of results #}
        var resultsTitle = $.sprintf("{{getConstant('_DPAD_DBCONSTANT_EIBDATALOG_VIEW_RESULTS_TITLE')}}",response.log.data.length,response.log.counter);
        $(this.getScopeSelector()).find("#eiblog_items_tot").html(resultsTitle);
        
        {# Filling log data array with new incoming data #}
        this.lastReceivedLogId = 0;
        if(response.log.data.length > 0)
        {
            this.logData = response.log.data.slice(0);
            for(var i in this.logData){
                this.lastReceivedLogId = Math.max(this.lastReceivedLogId,parseInt(this.logData[i]["ID"]));
            }
        }
        else
        {
            this.logData = new Array();
        }
        
        {# Rendering log #}
        this.logRender();
    }
    
    {# This function exports log in desired format #}
    this.logExport = function(format)
    {
        {# Identifying and passing filters to log load ajax function #}
        var srcaddr = $(this.getScopeSelector()).find("input#srcaddr").val();
        var dstaddr = $(this.getScopeSelector()).find("input#dstaddr").val();
        var payload = $(this.getScopeSelector()).find("input#payload").val();
        var date_from = this.realtimeMode==true ? '' : $(this.getScopeSelector()).find("#date_from").val();
        var date_to = this.realtimeMode==true ? '' : $(this.getScopeSelector()).find("#date_to").val();

        {# Determining if we want a limited or full export #}
        var limit = this.limit;
        if(confirm("{{getConstant('_DPAD_DBCONSTANT_EIBDATALOG_VIEW_MESSAGE_EXPORT_REQUEST_NO_LIMIT')|encode4jscript}}"))   limit = this.limitForExport;
        
        {# Initializing URL #}
        var url = "../eibdatalog/eiblog_getdata.php?srcaddr="+srcaddr+"&dstaddr="+dstaddr+"&payload="+payload+"&date_from="+date_from+"&date_to="+date_to+"&offset="+this.offset+"&limit="+limit+"&last_log_id="+this.lastRequestedLogId+"&language="+rM.getConfiguration("current_language",{refresh:false})+"&format="+format;
        
        {# Redirecting export iframe to URL #}
        $(this.getScopeSelector()).find("#eiblog_export_download_iframe").attr("src",url);
        
        {# Displaying a message to user #}
        this.messageId = this.updateMessage(this.messageId,"{{getConstant('_DPAD_DBCONSTANT_EIBDATALOG_VIEW_MESSAGE_EXPORT_IN_PROGRESS')|encode4jscript}}","info",150);
    }
    
    {# This function renders log data #}
    this.logRender = function()
    {
        var result_array = this.logData;
        
        {{ jsBlock({
                'operation':'render',
                'block_name':'block_eiblog',
                'block_render_callback':'$.proxy(this._logRenderCallback,this)'
        }) }}
    }
    
    this._logRenderCallback = function()
    {
        {# Scrolling to the end of page #}
        {# $("#template-content-work").scrollTo("100%"); #}
        
        themeManager.waitplease_display(false);

        {# In case of real-time mode, scheduling next call #}
        if(this.realtimeMode == true)
        {
            this.realtimeHandler = setTimeout(this.getScope(true)+".logRefresh()",this.realtimeTimer*1000);
        }
    }

    {# This function refreshes log with last settings #}
    this.logRefresh = function()
    {
        clearTimeout(this.realtimeHandler);
        this.logLoad();
    }
    
    {# This function empties log #}
    this.logEmpty = function()
    {
        {# This function is available only in real-time mode #}
        if(this.realtimeMode != true)   return;
        
        this.lastRequestedLogId = this.lastReceivedLogId;
        
        this.logRefresh();
    }
    
    {# This function changes log results offset #}
    this.offsetChange = function(offset)
    {
        this.offset = offset;
        this.logRefresh();
    }
    
    {# This function changes log results page #}
    this.pagerSeek = function(pageNum)
    {
        if(pageNum<=0)  pageNum=1;
        if(pageNum>=this.pageTot)   pageNum=this.pageTot;

        var offset = (pageNum-1)*this.limit;

        this.offsetChange(offset);
    }

    {# This function increases current page #}
    this.pagerNext = function()
    {
        this.pagerSeek(this.pageCurr+1);
    }

    {# This function decreases current page #}
    this.pagerPrev = function()
    {
        this.pagerSeek(this.pageCurr-1);
    }

    {# This function updates paging elements #}
    this.pagerUpdate = function()
    {
        $(this.getScopeSelector()).find("#objs_number").val(this.pageCurr);
        $(this.getScopeSelector()).find("#page_tot").html(this.pageTot);
    }
        
    {# This function toggles between real-time mode ON/OFF #}
    this.realtimeToggle = function()
    {
        this.realtimeMode = !this.realtimeMode;
        
        if(this.realtimeMode==true)
        {
            $(this.getScopeSelector()).find("#pager,#button_refresh,#date_from,#date_to").css("opacity",0.5).filter("#date_from,#date_to").attr('disabled', 'disabled');
            $(this.getScopeSelector()).find("[id='button_empty']").css("opacity",1);
            $(this.getScopeSelector()).find("[id='button_realtime']").removeClass("field-button-gray").addClass("field-button-orange");
            $(this.getScopeSelector()).find("[id='button_empty']").removeClass("field-button-gray").addClass("field-button-yellow");
            $(this.getScopeSelector()).find("[id='button_refresh']").addClass("field-button-gray").removeClass("field-button-green");
            this.pageCurr = 1;
            this.pageTot = 1;
            this.offset = 0;
            this.limit = 100;

            {# Calling manually a log clear #}
            this.logEmpty();
        }
        else
        {
            $(this.getScopeSelector()).find("#pager,#button_refresh,#date_from,#date_to").css("opacity",1).filter("#date_from,#date_to").removeAttr('disabled');
            $(this.getScopeSelector()).find("[id='button_empty']").css("opacity",0.5);
            $(this.getScopeSelector()).find("[id='button_realtime']").addClass("field-button-gray").removeClass("field-button-orange");
            $(this.getScopeSelector()).find("[id='button_empty']").addClass("field-button-gray").removeClass("field-button-yellow");
            $(this.getScopeSelector()).find("[id='button_refresh']").removeClass("field-button-gray").addClass("field-button-green");
            
            clearTimeout(this.realtimeHandler);
            
            this.lastRequestedLogId = '';

            {# Calling manually a log refresh #}
            this.logRefresh();
        }
        
    }
    
    {# This function returns a formatted version of payload #}
    this.payloadGetFormatted = function(eisType,payloadEncoded,payloadRaw)
    {
        var payloadFormatted = "";
        
        {# Formatting encoded value #}
        switch(eisType)
        {
            case "2V":
                payloadFormatted = $.sprintf("%s%%",payloadEncoded);
                break;
            default:
                payloadFormatted = payloadEncoded;
        }
        
        {# Enqueuing raw payload #}
        payloadFormatted += " ($" + payloadRaw + ")";
        
        return payloadFormatted;
    }
    
    
    this.detect_enter_keypress=function(keypressed) {
        var keycode;
        if(window.event)keycode = window.event.keyCode;
        else if(keypressed)keycode = keypressed.which;
        else return false;
        var result=(keycode == 13);
            if(result==true && keypressed)$(keypressed.currentTarget).blur();
            return result;
    }
    
    
{% endblock %}

{% block block_existModifiedForms %}
    return true;
{% endblock %}
