{% extends "scope.administration_page.tpl" %}

{% block block_includeJs %}
    {{ parent() }}
    {{ html_includejs("jsDpadBlock.js","js") }}
    {{ html_includejs("jquery.ui.sortable.js","js") }}
    {{ html_includejs("jquery.scrollTo.js","js") }}
{% endblock %}

{% block block_customDeclarations %}
        
        this.logData = new Array();
        this.offset = 0;                        //Default data offset
        this.limit = 100;                       //Default maximum number of items retrieved at once
        this.limitForExport = 25000;            //Default maximum number of items exported
        this.pageCurr = 1;                      //Current page in case of multiple pages
        this.pageTot = 1;                       //Number of pages in case of multiple pages
        this.lastReceivedLogId = '';            //Last received log item ID from server
        this.lastRequestedLogId = '';           //Last requested log item ID to server
        this.type = '';                         //Type of entry to be retrieved from log
        
        {{ jsBlock({
		'operation':"declaration",
		'block_name':"block_syslog",
		'block_render_container_selector':"this.getScopeSelector()+' #syslog_container'",
		'prototype_container':"$(this.getScopeSelector()).find('#block_syslog_container_prototype').html();",
		'prototype_header':"$(this.getScopeSelector()).find('#block_syslog_header_prototype > tbody').html();",
		'prototype_item':"$(this.getScopeSelector()).find('#block_syslog_item_prototype > tbody').html();"
	}) }}
{% endblock %}

{% block block_onLoad_pageInit %}{% endblock %}
{% block block_onLoad %}

        if(!this.isInitialized)
        {
                {# Init Masks#}
                $(this.getScopeSelector()).find('input[mask]').each(function(){
                        $(this).mask($(this).attr('mask'));
                });
        }

        {# Initializing help #}
        this.initHelp();
        
	{# Showing/hiding elements depending on currently expert mode #}
	wM.expertModeToggle(wM.expertMode,true);

        {# Loading log #}
        this.logRefresh();

{% endblock %}

{% block block_onUnload %}
{% endblock block_onUnload %}

{% block block_formValidate %}{% endblock %}
{% block block_formButtonSubmit %}{% endblock %}
{% block block_formButtonSubmitCompleted %}{% endblock %}
{% block block_formSubmitCallback %}{% endblock %}

{% block block_formButtonClose %}
{# If workspace manager is not enabled, skipping #}
if(!wM.enabled && skipEnableCheck != true)  return;
{{ parent() }}
{# Closing tab corresponding to current page #}
wM.tabRemove(this.getTab());
{% endblock %}

{% block block_customFunctions %}
{% include "include.workspace_page_functions.tpl" %}

    {# This function loads log #}
    this.logLoad = function(){

        {# Identifying and passing filters to log load ajax function #}
        var date_from = $(this.getScopeSelector()).find("#date_from").val();
        var date_to = $(this.getScopeSelector()).find("#date_to").val();
        var keyword = $(this.getScopeSelector()).find("#keyword").val();

        themeManager.waitplease_display(true);
        
        {# Performing AJAX call retrieving data #}
        rM.ajax({
            type: 'GET',
            url: '../system/syslog_getdata.php',
            dataType:'json',
            data: {
                    type:this.type,
                    keyword:keyword,
                    date_from: date_from,
                    date_to: date_to,
                    offset:this.offset,
                    limit:this.limit,
                    last_log_id:this.lastRequestedLogId,
                    language:rM.getConfiguration("current_language",{refresh:false})
            },
            success:$.proxy(this.logLoadCallback,this)
        });
        
    }
    this.logLoadCallback = function(response){

        {# Handling result #}
        if(parseInt(response.result)!={{getConstant("_DPAD_RESULT_NOERROR")}})
        {
            var message = response.message ? response.message : "{{getConstant('_DPAD_DBCONSTANT_SYSDATALOG_VIEW_MESSAGE_ERROR_LOADING_LOG')|encode4jscript}}";
            this.messageId = this.updateMessage(this.messageId,message,"warn",10);
            return;
        }

        {# Updating paging #}
        this.pageTot = Math.max(1,Math.ceil(parseInt(response.log.counter)/this.limit));
        this.pageCurr = Math.ceil((this.offset+1)/this.limit);
        this.pagerUpdate();
        
        {# Updating total of results #}
        var resultsTitle = $.sprintf("{{getConstant('_DPAD_DBCONSTANT_SYSDATALOG_VIEW_RESULTS_TITLE')}}",response.log.data.length,response.log.counter);
        $(this.getScopeSelector()).find("#syslog_items_tot").html(resultsTitle);
        
        {# Filling log data array with new incoming data #}
        if(response.log.data.length > 0)
        {
            this.logData = response.log.data.slice(0);
            this.lastReceivedLogId = response.log.data[0]["ID"];
        }
        else
        {
            this.logData = new Array();
        }
        
        {# Rendering log #}
        this.logRender();
    }
    
    {# This function exports log in desired format #}
    this.logExport = function(format)
    {
        {# Identifying and passing filters to log load ajax function #}
        var date_from = $(this.getScopeSelector()).find("#date_from").val();
        var date_to = $(this.getScopeSelector()).find("#date_to").val();
        var keyword = $(this.getScopeSelector()).find("#keyword").val();

        {# Determining if we want a limited or full export #}
        var limit = this.limit;
        if(confirm("{{getConstant('_DPAD_DBCONSTANT_SYSDATALOG_VIEW_MESSAGE_EXPORT_REQUEST_NO_LIMIT')|encode4jscript}}"))   limit = this.limitForExport;
        
        {# Initializing URL #}
        var url = "../system/syslog_getdata.php?type="+this.type+"&keyword="+keyword+"&date_from="+date_from+"&date_to="+date_to+"&offset="+this.offset+"&limit="+limit+"&last_log_id="+this.lastRequestedLogId+"&language="+rM.getConfiguration("current_language",{refresh:false})+"&format="+format;
        
        {# Redirecting export iframe to URL #}
        $(this.getScopeSelector()).find("#syslog_export_download_iframe").attr("src",url);
        
        {# Displaying a message to user #}
        this.messageId = this.updateMessage(this.messageId,"{{getConstant('_DPAD_DBCONSTANT_SYSDATALOG_VIEW_MESSAGE_EXPORT_IN_PROGRESS')|encode4jscript}}","info",150);
    }
    
    {# This function renders log data #}
    this.logRender = function()
    {
        var result_array = this.logData;
        
        {{ jsBlock({
                'operation':'render',
                'block_name':'block_syslog',
                'block_render_callback':'$.proxy(this._logRenderCallback,this)'
        }) }}
    }
    
    this._logRenderCallback = function()
    {
        {# Scrolling to the end of page #}
        {# $("#template-content-work").scrollTo("100%"); #}
        
        {# Showing/hiding columns depending on type #}
        switch(this.type)
        {
            case "NOTIFY_VIDEO":
            
                break;
            default:
                $(this.getScopeSelector()).find("[column='is_handled'],[column='handled_datetime']").hide();
                break;
        }
        
        themeManager.waitplease_display(false);
    }

    {# This function refreshes log with last settings #}
    this.logRefresh = function()
    {
        this.logLoad();
    }
    
    {# This function changes log results offset #}
    this.offsetChange = function(offset)
    {
        this.offset = offset;
        this.logRefresh();
    }
    
    {# This function changes log results page #}
    this.pagerSeek = function(pageNum)
    {
        if(pageNum<=0)  pageNum=1;
        if(pageNum>=this.pageTot)   pageNum=this.pageTot;

        var offset = (pageNum-1)*this.limit;

        this.offsetChange(offset);
    }

    {# This function increases current page #}
    this.pagerNext = function()
    {
        this.pagerSeek(this.pageCurr+1);
    }

    {# This function decreases current page #}
    this.pagerPrev = function()
    {
        this.pagerSeek(this.pageCurr-1);
    }

    {# This function updates paging elements #}
    this.pagerUpdate = function()
    {
        $(this.getScopeSelector()).find("#objs_number").val(this.pageCurr);
        $(this.getScopeSelector()).find("#page_tot").html(this.pageTot);
    }
        
    this.detect_enter_keypress=function(keypressed) {
        var keycode;
        if(window.event)keycode = window.event.keyCode;
        else if(keypressed)keycode = keypressed.which;
        else return false;
        var result=(keycode == 13);
            if(result==true && keypressed)$(keypressed.currentTarget).blur();
            return result;
    }
    
    {# This function handles a message #}
    this.msgHandle = function(msgId,isHandled)
    {
	var handleFlag = (isHandled?"1":"0");
        var timeStamp = new Date().getTime()/1000;
	var handleTimestamp = (isHandled?timeStamp:"");
        
        var query = "UPDATE DPAD_LOG SET IS_HANDLED='"+handleFlag+"',HANDLED_TIMESTAMP='"+handleTimestamp+"' WHERE ID='"+msgId+"'";
	dbManager.executeSQL(query,Math.random(),$.proxy(this.msgHandleCallback,this,msgId));
    }
    this.msgHandleCallback = function(msgId,result_array)
    {
        this.logRefresh();
    }
    
    {# This function deletes a message #}
    this.msgDelete = function(msgId)
    {
        var query = "DELETE FROM DPAD_LOG WHERE ID='"+msgId+"'";
	dbManager.executeSQL(query,Math.random(),$.proxy(this.msgDeleteCallback,this,msgId));
    }
    this.msgDeleteCallback = function(msgId,result_array)
    {
        this.logRefresh();
    }
    
{% endblock %}

{% block block_existModifiedForms %}
    return true;
{% endblock %}
