/**
	 * jQuery SHA1 hash algorithm function
	 * 
	 * 	<code>
	 * 		Calculate the sha1 hash of a String 
	 * 		String $.sha1 ( String str )
	 * 	</code>
	 * 
	 * Calculates the sha1 hash of str using the US Secure Hash Algorithm 1.
	 * SHA-1 the Secure Hash Algorithm (SHA) was developed by NIST and is specified in the Secure Hash Standard (SHS, FIPS 180).
	 * This script is used to process variable length message into a fixed-length output using the SHA-1 algorithm. It is fully compatible with UTF-8 encoding.
	 * If you plan using UTF-8 encoding in your project don't forget to set the page encoding to UTF-8 (Content-Type meta tag).
	 * This function orginally get from the WebToolkit and rewrite for using as the jQuery plugin.
	 * 
	 * Example
	 * 	Code
	 * 		<code>
	 * 			$.sha1("I'm Persian."); 
	 * 		</code>
	 * 	Result
	 * 		<code>
	 * 			"1d302f9dc925d62fc859055999d2052e274513ed"
	 * 		</code>
	 * 
	 * @alias Muhammad Hussein Fattahizadeh < muhammad [AT] semnanweb [DOT] com >
	 * @link http://www.semnanweb.com/jquery-plugin/sha1.html
	 * @see http://www.webtoolkit.info/
	 * @license http://www.gnu.org/licenses/gpl.html [GNU General Public License]
	 * @param {jQuery} {sha1:function(string))
	 * @return string
	 */(function(a){var b=function(a,b){return a<<b|a>>>32-b},c=function(a){var b="",c,d,e;for(c=0;c<=6;c+=2)d=a>>>c*4+4&15,e=a>>>c*4&15,b+=d.toString(16)+e.toString(16);return b},d=function(a){var b="",c,d;for(c=7;c>=0;c--)d=a>>>c*4&15,b+=d.toString(16);return b},e=function(a){a=a.replace(/\x0d\x0a/g,"\n");var b="";for(var c=0;c<a.length;c++){var d=a.charCodeAt(c);d<128?b+=String.fromCharCode(d):d>127&&d<2048?(b+=String.fromCharCode(d>>6|192),b+=String.fromCharCode(d&63|128)):(b+=String.fromCharCode(d>>12|224),b+=String.fromCharCode(d>>6&63|128),b+=String.fromCharCode(d&63|128))}return b};a.extend({sha1:function(a){var c,f,g,h=new Array(80),i=1732584193,j=4023233417,k=2562383102,l=271733878,m=3285377520,n,o,p,q,r,s;a=e(a);var t=a.length,u=new Array;for(f=0;f<t-3;f+=4)g=a.charCodeAt(f)<<24|a.charCodeAt(f+1)<<16|a.charCodeAt(f+2)<<8|a.charCodeAt(f+3),u.push(g);switch(t%4){case 0:f=2147483648;break;case 1:f=a.charCodeAt(t-1)<<24|8388608;break;case 2:f=a.charCodeAt(t-2)<<24|a.charCodeAt(t-1)<<16|32768;break;case 3:f=a.charCodeAt(t-3)<<24|a.charCodeAt(t-2)<<16|a.charCodeAt(t-1)<<8|128}u.push(f);while(u.length%16!=14)u.push(0);u.push(t>>>29),u.push(t<<3&4294967295);for(c=0;c<u.length;c+=16){for(f=0;f<16;f++)h[f]=u[c+f];for(f=16;f<=79;f++)h[f]=b(h[f-3]^h[f-8]^h[f-14]^h[f-16],1);n=i,o=j,p=k,q=l,r=m;for(f=0;f<=19;f++)s=b(n,5)+(o&p|~o&q)+r+h[f]+1518500249&4294967295,r=q,q=p,p=b(o,30),o=n,n=s;for(f=20;f<=39;f++)s=b(n,5)+(o^p^q)+r+h[f]+1859775393&4294967295,r=q,q=p,p=b(o,30),o=n,n=s;for(f=40;f<=59;f++)s=b(n,5)+(o&p|o&q|p&q)+r+h[f]+2400959708&4294967295,r=q,q=p,p=b(o,30),o=n,n=s;for(f=60;f<=79;f++)s=b(n,5)+(o^p^q)+r+h[f]+3395469782&4294967295,r=q,q=p,p=b(o,30),o=n,n=s;i=i+n&4294967295,j=j+o&4294967295,k=k+p&4294967295,l=l+q&4294967295,m=m+r&4294967295}var s=d(i)+d(j)+d(k)+d(l)+d(m);return s.toLowerCase()}})})(jQuery);