{% extends "scope.energymanager.tpl" %}

{% block block_chartsUpdate %}

    {# Initializing chart #}
    this.chartInit();
    
    {# Retrieving objects by currently shown tag #}
    var objIds = this.getBatteryItemsByTag("energymanager",this.dimension+"_value");
    
    this.chartObjectsNum = 0;
    
    {# Scanning objects; calling AJAX data retrieve for each of them #}
    for(var i in objIds)
    {
        if(objIds[i]==-1)   continue;
        
        var serieBattery = objM.getObj(this.getBatteryIdByItemId("energymanager",objIds[i],this.dimension+"_value"));
        var scaleFactor = (typeof(serieBattery.options.chart_scalefactor)!='undefined' ? parseFloat(serieBattery.options.chart_scalefactor) : 1);

        this.chartObjectsNum++;

        rM.ajax({
                type:'POST',
                async:true,
                url:'../reporting/track_getdata.php',
                data:'id='+objIds[i]+'&interval='+this.period+'&number='+i+'&dimension=int&factor=' + scaleFactor,
                dataType:'json',
                success:$.proxy(this.chartsUpdateCallback,this),
                error:$.proxy(this.chartsUpdateCallback,this)
        });
        
    }
    
    clearTimeout(this.chartRefreshTimeoutHandler);
    this.chartRefreshTimeoutHandler = setTimeout(this.getScope(true)+'.chartsUpdate()',this.chartRefreshTimeout*1000);

{% endblock block_chartsUpdate %}

{% block block_chartsUpdateCallback %}

    {# Handling errors #}
    if(parseInt(response.result)!=0)
    {
        console.error("Cannot retrieve data for energy summary chart (Code %s, Message: '%s')",response.result,response.message);
        return;
    }
    
    {# If series ticks contain multilanguage constants, converting them into strings #}
    if(response.series)
    {
        for(var s in response.series)
        {
                for(var i in response.series[s].ticks)
                {
                        if(response.series[s].ticks[i][1].indexOf('_DPAD')>=0)
                        {
                                response.series[s].ticks[i][1] = rM.getConstant(response.series[s].ticks[i][1]);
                        }
                }
        }
    }
    
    {# Updating chart options #}
    var chartOptions = {
                        xaxis: {ticks:response.series.current.ticks},
                        legend: { show: true,position:"ne", margin:0, backgroundOpacity:0, container: $(this.getScopeSelector()).find("#energy-chart-legend"), noColumns: Math.min(this.chartObjectsNum,this.chartLegendItemColumns )}
                    };
    this.chartSetOptions(chartOptions);
    
    {# Identifying current object and corresponding battery #}
    var serieObj = objM.getObj(response.object);
    var serieBattery = objM.getObj(this.getBatteryIdByItemId("energymanager",serieObj.id,this.dimension+"_value"));
    
    {# Initilizing serie color #}
    var serieColor = this.chartColors[response.number];

    {# Initializing serie flags #}
    var serieShowFlag = this.batteryGetChartFlag(serieBattery.id,"show");
    var serieRangeFlag = this.batteryGetChartFlag(serieBattery.id,"range");
    var serieCompareFlag = this.batteryGetChartFlag(serieBattery.id,"compare");
    
    {# Initializing measure unit #}
    var serieFormattingSchema = (typeof(serieBattery.options.chart_measureunit) != 'undefined')  ? "%0.2f " + serieBattery.options.chart_measureunit: serieObj._rendering.formatting_schema;
    
    {# Initializing label for serie, with synthesis data #}
    var serieLabel = serieBattery.name;
    if(!isNaN(response.series.synthesis.int))     serieLabel += "<br/>" + $.sprintf(serieFormattingSchema,response.series.synthesis.int) + "";

    {# Adding series for both current and reference data, if range is enabled #}
    for(var i in response.series.average.max)
    {
        response.series.average.max[i].push(response.series.average.min[i][1]);
    }
    this.chartAddSerie(serieObj.id+".range",{id:serieObj.id+".range",data:response.series.average.max, lines: { show: true, lineWidth: 0.2, fill: 0.2 }, color: serieColor},(serieShowFlag && serieRangeFlag));

    this.chartAddSerie(serieObj.id+".show",{id:serieObj.id+".show",label:serieLabel,data:response.series.current.int,bars:{show: true, barWidth: 0.5,align:"center",fill: 0.4,lineWidth:1},color: serieColor},(serieShowFlag));
    this.chartAddSerie(serieObj.id+".compare",{id:serieObj.id+".compare",data:response.series.average.int,lines:{show: true, lineWidth: 0.5},points: { show: true, fill: false }, color: serieColor},(serieShowFlag && serieCompareFlag));
    
    
    
    {# Plotting chart #}
    this.chartDraw();
    
{% endblock block_chartsUpdateCallback %}

{% block block_chartsUpdateByDimension %}
    {{parent()}}
    
    {# Re-rendering batteries #}
    var batteries = this.getBatteries("energymanager");
    for(var i in batteries)
    {
        var battery = batteries[i];
        $(this.getScopeSelector()).find("#block_energymanager_item_"+battery.id).html(battery.render(this.dimension));
    }
    
{% endblock block_chartsUpdateByDimension %}


{% block block_onUnload %}
{{parent()}}
clearTimeout(this.chartRefreshTimeoutHandler);
{% endblock block_onUnload %}

