{% extends "core/templates/scope.plan.tpl" %}

{% block block_includeJsCustom %}
{{ html_includejs("jsDpadObjectManager.js","js") }}
{{ html_includejs("jsDpadMenuManager.js","js") }}
{% endblock %}

{% block block_declarationsCustom %}

    this._bCompassActive = false;
    this._bCompassCalibrated = false;
    this._iCompassOffset1 = 0;
    this._iCompassOffset2 = 0;
    this._iCompassMode = 0;                     //Available modes: 0 (top view), 1 (side view / panorama)
    this._iCompassDegrees = 0;
    this._iCompassDegreesPrev = 0;
    this._bCompassCalibrating = false;          //True during calibration
    this._iCompassCalibrateStep = 0;        
    this._iCompassLongPressTimeout = 2;
    this._hCompassLongPressTimeout;
    this._bCompassLongPress = false;
    
    this._iTiltDegrees = 0;
    
    this._bPlanMoving = false;
    this._iPlanMovingTimer = 0.25;
    this._hPlanMovingTimerHandler;
    
    this.compassNeedle = $(this.getScopeSelector()).find(".compass-needle");
    this.compassWidget = $(this.getScopeSelector()).find(".compass-widget");
    this.compassCalibrate = $(this.getScopeSelector()).find(".compass-calibrate");

    themeManager.home_id = {{template.homepage_id}};
    themeManager.prefs_id = {{template.favourites_id}};
    
    this._bInitialized = false;

{% endblock block_declarationsCustom %}

{% block block_onLoad %}
{{ parent() }}
if( objM.has_permission('edit_plan') ){
	themeManager.toolbarButtonShowHide("template-action-plan",true);
}
if( themeManager.deviceOrientationIsSupported() ){
    if(this.compassWidget){
        this.compassWidget.on('click.compass',$.proxy(this.compassToggle,this));
        this.compassWidget.on('mousedown.compass touchstart.compass',$.proxy(this.compassLongPressStart,this));
    }
    if(this.compassCalibrate){
        this.compassCalibrate.on('click.compass',$.proxy(this.compassDoCalibrate,this));
    }
    this._planMovingEnd();
}
{% endblock block_onLoad %}

{% block block_onTransitionDone %}
	if( themeManager.deviceOrientationIsSupported() ){
		var _oObj = objM.getObj(this.id);
		if( typeof(_oObj.options.orientation_enabled)!='undefined' )      this._bOrientationEnabled =    (parseInt(_oObj.options.orientation_enabled)==1);
		if( this._bOrientationEnabled ){
			if( typeof(_oObj.options.compass_active)!='undefined' )        this._bCompassActive =  ( parseInt(_oObj.options.compass_active)==1 );
			if( typeof(_oObj.options.compass_calibrated)!='undefined' )    this._bCompassCalibrated =  ( parseInt(_oObj.options.compass_calibrated)==1 );
			if( typeof(_oObj.options.compass_offset1)!='undefined' )       this._iCompassOffset1 = _oObj.options.compass_offset1;
			if( typeof(_oObj.options.compass_offset2)!='undefined' )       this._iCompassOffset2 = _oObj.options.compass_offset2;
			if( typeof(_oObj.options.compass_mode)!='undefined' )          this._iCompassMode =    _oObj.options.compass_mode;
		}
	}
	{% block block_blockRenderBackground %}
    if( !this._bInitialized ){
        var myHeaderImage = objM.getObj(this.id).options.background_image_path;
        if( myHeaderImage!='' && typeof(myHeaderImage)!='undefined' ){
			myHeaderImage = rM.getServerWebPath()+'./modules/supervision/images/background/'+encodeURI(myHeaderImage);
			$(this.getScopeSelector()).find('#template-' + this._sCurrentView + '-background').attr('src',myHeaderImage);
        }
    }
    {% endblock block_blockRenderBackground %}
	this._bInitialized = true;
	{{ parent() }}
{% endblock block_onTransitionDone %}

{% block block_onUnload %}
{{ parent() }}
themeManager.toolbarButtonShowHide("template-action-plan",false);

if( themeManager.deviceOrientationIsSupported() ){
    if(this.compassWidget){
        this.compassWidget.off('click.compass');
        this.compassWidget.off('mousedown.compass touchstart.compass');
    }
    if(this.compassCalibrate){
        this.compassCalibrate.off('click.compass');
    }
    clearTimeout(this._hPlanMovingTimerHandler);
    clearTimeout(this._hCompassLongPressTimeout);
}
{% endblock block_onUnload %}

{% block block_render %}

    {% block block_blockRenderPageTitle %}
    {# Setting header title with current object name #}
    themeManager.setHeaderTitle(objM.getObj(this.id).name);
    {% endblock block_blockRenderPageTitle %}

    {% block block_blockRenderAdditionalAttributes %}
    {# Setting additional attributes to each object before rendering #}
    for (var i in result_array) {
            if( objM.hasRelation(themeManager.prefs_id,result_array[i]['ID']) ){
                    result_array[i]['PREFS'] = "on";
            } else {
                    result_array[i]['PREFS'] = "off";
            }
            var currObj = objM.getObj(result_array[i]['ID']);
			if( currObj ){
				if( currObj.is_complex==1 ){
					result_array[i]['ALLOW_SCHEDULE'] = objM.objGetChildIdByRelationOption(result_array[i]['ID'],"allow_schedule",1)>0?"on":"off";
				} else {
					result_array[i]['ALLOW_SCHEDULE'] =  currObj.is_writable?"on":"off";
				}
			}
    }
    {% endblock block_blockRenderAdditionalAttributes %}

    {{ parent() }}
{% endblock block_render %}

{% block block_editModeToggle %}
	if( activate_flag==true ){
		iM.openInstance("../system/loadtemplate.php?tpl=plan.edit",null,null,"right_panel");
		$(this.getScopeSelector()).find("#plan_container").addClass("editing");
	} else {
		$(this.getScopeSelector()).find("#plan_container").removeClass("editing");
	}
	{{ parent() }}
{% endblock block_editModeToggle %}

{% block block_editModeOptionSetOptions %}
	{# Setting option as HTML attribute on current item #}
	var _oCurrentItem = $(this.getScopeSelector()).find("#block_plan_item_" + iRelationID);
	_oCurrentItem.attr(option_name,option_value);
	{# Handling specific options #}
	switch(option_name){
		case 'show_label':
			{% block block_editModeOptionSetOptionsLabel %}
			if( option_value==true||option_value=="'true'" ){
				_oCurrentItem.addClass('object-box-full-width');
			} else {
				_oCurrentItem.removeClass('object-box-full-width');
			}
			{% endblock block_editModeOptionSetOptionsLabel %}
		break;
		case 'hide_shadow':
			{% block block_editModeOptionSetOptionsShadow %}
			if( option_value==true||option_value=="'true'" ){
				_oCurrentItem.addClass("object-box-no-bg");
			} else {
				_oCurrentItem.removeClass("object-box-no-bg");
			}
			{% endblock block_editModeOptionSetOptionsShadow %}
		break;
	}
{% endblock block_editModeOptionSetOptions %}

{% block block_editModeGetElementOptionals %}
	oCurrentOptionals.show_label=(jObj.hasClass('object-box-full-width')?true:false);
	oCurrentOptionals.hide_shadow=(jObj.hasClass('object-box-no-bg')?true:false);
{% endblock block_editModeGetElementOptionals %}

{% block editModeRestore_optionals %}
	{# handling "hide_shadow" #}
	if( oCurrentOptionals.hide_shadow!=oCurrentOriginalOptionals.hide_shadow ){
		this.editModeOptionSet( _iRelationID,'hide_shadow',oCurrentOriginalOptionals.hide_shadow,false);
	}
	{# handling "show_label" #}
	if( oCurrentOptionals.show_label!=oCurrentOriginalOptionals.show_label ){
		this.editModeOptionSet( _iRelationID,'show_label',oCurrentOriginalOptionals.show_label,false);
	}
{% endblock editModeRestore_optionals %}

{% block deviceDirectionChanged %}
{{parent()}}

if(!this._bOrientationEnabled)  return;

if(!this._bCompassInitialized){
    this.compassWidget.show();
    this.compassEnableDisable(this._bCompassActive);
}

switch(this._iCompassMode){
    case 1:
        break;
    case 0:
    default:
        {# Normalizing degrees "around" last value in order to avoid jumps in rotation effect #}
        if(degrees>(this._iCompassDegreesPrev+180))	degrees-=360;
        if(degrees<(this._iCompassDegreesPrev-180))	degrees+=360;
        if(degrees==360) degrees=0;
        break;
}

this._iCompassDegrees = degrees;

this.compassDoRotate();
if(this._bCompassActive)  this.planDoMove();
this._iCompassDegreesPrev = this._iCompassDegrees;

{% endblock deviceDirectionChanged %}

{% block deviceTiltChanged %}
{{parent()}}
this._iTiltDegrees = tilt;
if(this._bCompassCalibrating){
    if(this._iCompassCalibrateStep==0){
        this._iCompassMode = (this._iTiltDegrees>=45) ? 1 : 0;
        this.compassCalibrateUpdateCaption();
    }
} else {
    switch(this._iCompassMode){
        case 1:
            this.planDoMove();
            break;
        case 0:
        default:
            break;
    }
}
{% endblock deviceTiltChanged %}

{% block block_isScrollable %}
var _bScrollable = !this.block_plan_edit_mode;
if(_bScrollable && themeManager.deviceOrientationIsSupported() && this._bOrientationEnabled){
    _bScrollable = !this._bCompassActive || (this._iCompassMode==0);
}
return _bScrollable;
{% endblock block_isScrollable %}

{% block _customScope %}
this.compassToggle = function(){
    this._bCompassLongPress = false;
    clearTimeout(this._hCompassLongPressTimeout);
    this.compassEnableDisable(this.compassWidget.hasClass("off"));
}

this.compassLongPressStart = function(){
    if(this._bCompassLongPress) return;
    this._hCompassLongPressTimeout = setTimeout($.proxy(this.compassLongPressDo,this),this._iCompassLongPressTimeout*1000);
    this._bCompassLongPress = true;
}

this.compassLongPressDo = function(){
    if(!this._bCompassLongPress){return;}
    this.compassEnableDisable(false);
    this.compassCalibrateShowHide(true);
}

this.compassEnableDisable = function(enableFlag)
{
    if(enableFlag && !this._bCompassCalibrating){
        this.compassWidget.removeClass("off").addClass("on");
        
        if(!this._bCompassCalibrated){
            if(this._bCompassCalibrating){
                themeManager.showMessage("{{getConstant('_DPAD_THEME_PLAN_COMPASS_CALIBRATE_ABORTED_MESSAGE')|encode4jscript}}","info",2);
                this.compassCalibrateShowHide(false);
            } else {
                this.compassCalibrateShowHide(true);
            }
        } else {
            themeManager.showMessage("{{getConstant('_DPAD_THEME_PLAN_COMPASS_CALIBRATE_INFO_MESSAGE')|encode4jscript}}","info",2);

            this._bCompassActive=true;
            objM.updateFieldObj(this.id,"options.compass_active",1);
            
            this._resetScrollable();
            $(this.getScopeSelector()).find("#template-plan-container").css("overflow","hidden");
            this.planDoMove();
        }
    } else {
        this._bCompassActive=true;
        if(this._bCompassCalibrating){
            this.compassCalibrateShowHide(false);        
        }
        this.compassWidget.removeClass("on").addClass("off");
        this.planDoMove(0,100);
        objM.updateFieldObj(this.id,"options.compass_active",0);
        $(this.getScopeSelector()).find("#template-plan-container").css("overflow","");
        this._bCompassActive=false;
    }
    
    {#Updating background scrollable state #}
    this._setScrollable();
}

this.planDoMove = function(direction,tilt){
    if(!this._bCompassActive) return;
    if(this._bPlanMoving==true) return;
    
    switch(this._iCompassMode){
        case 1:     //Panorama view

            var percentX = direction;
            if(typeof(percentX)=='undefined'){
                direction = this._iCompassDegrees;
                
                var azimuth = (this._iCompassOffset1 - this._iCompassOffset2 ) / 2 + this._iCompassOffset2 - 180;
                if(azimuth < 0) azimuth += 360;
                
                if(this._iCompassOffset2 >= 0){
                    if(direction < azimuth)  direction += 360;
                } else {
                    if(direction > azimuth)  direction -= 360;
                }

                percentX = Math.round((this._iCompassOffset1 - direction) / (this._iCompassOffset1 - this._iCompassOffset2) * 100);
                console.info("direction is %o, normalized is %o being azimuth %o, offsets are %o and %o, percentX is %o",this._iCompassDegrees,direction,azimuth,this._iCompassOffset1,this._iCompassOffset2,percentX);
                percentX = Math.min(100,Math.max(0,percentX));
            }
            
            if(typeof(tilt)=='undefined')   tilt = this._iTiltDegrees;
            var percentY = Math.min(100,Math.max(0,Math.round((tilt -45) / 45 * 100)));    

            this.planDoTranslate(percentX,percentY);
            
            break;

        case 0:     //Top view
        default:
        
            var degrees = direction;
            if(typeof(degrees)=='undefined')    degrees = this._iCompassDegrees-this._iCompassOffset1;

            this.planDoRotate(degrees);
            break;

    }
    this._planMovingStart();
    
}

this.planDoRotate = function(degrees){

    var planContainer = $(this.getScopeSelector()).find("#plan_contained");

    planContainer.css("-webkit-transform","rotate3d(0,0,1, " + (degrees) + "deg)");
    planContainer.css("transform","rotate3d(0,0,1, " + (degrees) + "deg)");

    var planObjects = planContainer.find(".object-box").not("[type='GROUP']");
    planObjects.css("-webkit-transform","rotate3d(0,0,1, " + (-degrees) + "deg)");
    planObjects.css("transform","rotate3d(0,0,1, " + (-degrees) + "deg)");
}

this.planDoTranslate = function(percentX,percentY){

    var plan = $(this.getScopeSelector()).find("#plan_contained");
    var container = $(this.getScopeSelector()).find("#plan_container");
    
    var planW = Math.round(plan.width() * parseFloat(plan.css("zoom")));
    var planH = Math.round(plan.height() * parseFloat(plan.css("zoom")));

    var containerW = parseInt(container.width());
    var containerH = parseInt(container.height());
    
    var offsetX = Math.max(0,Math.round((planW - containerW) * percentX / 100));
    var offsetY = Math.max(0,Math.round((planH - containerH) * (100-percentY) / 100));

    plan.css("-webkit-transform","translate3d(-"+offsetX+"px,-"+offsetY+"px,0)");
    plan.css("transform","translate3d(-"+offsetX+"px,-"+offsetY+"px,0)");
    
    container.attr("translatex",offsetX);
    container.attr("translatey",offsetY);
}

this.compassDoRotate = function(){
    this.compassNeedle.css("webkitTransform","rotate3d(0,0,1, " + (this._iCompassDegrees) + "deg)");
    this.compassNeedle.css("transform","rotate3d(0,0,1, " + (this._iCompassDegrees) + "deg)");
}

this._planMovingStart = function(){
    this._bPlanMoving=true;
    this._hPlanMovingTimerHandler = setTimeout(this.getScope(true)+"._planMovingEnd();",this._iPlanMovingTimer*1000);
}


this._planMovingEnd = function(){
    this._bPlanMoving=false;
}

this.compassCalibrateShowHide = function(showFlag)
{
    this._iCompassCalibrateStep = 0;
    if(showFlag){
        this.compassCalibrateUpdateCaption();

        this.planDoMove(0,100);
        this._resetScrollable();

        this.compassCalibrate.show();
    }else{
        this.compassCalibrate.hide();
    }
    this._bCompassCalibrating = showFlag;
}

this.compassDoCalibrate = function(){
    
    this._bCompassActive = false;

    this._bCompassCalibrated = false;
    objM.updateFieldObj(this.id,"options.compass_calibrated",0);

    switch(this._iCompassCalibrateStep){
        case 0:     //Offset1 & mode selection
        
            {# Saving offset 1 #}
            this._iCompassOffset1 = this._iCompassDegrees;
            console.info("Plan rotation offset 1 is %o",this._iCompassOffset1);
            objM.updateFieldObj(this.id,"options.compass_offset1",this._iCompassOffset1);
            
            {# Saving rotation mode #}
            objM.updateFieldObj(this.id,"options.compass_mode",this._iCompassMode);
            
            {# Doing next step depending in current mode #}
            switch(this._iCompassMode){
                case 1:
                    this._iCompassCalibrateStep++;
                    this.planDoTranslate(100,100);
                    this.compassCalibrateUpdateCaption();
                    break;
                case 0:     //We do not need further calibration; closing...
                default:
                    this.compassEndCalibrate();
                    break;
            }

            break;

        case 1:     //Offset2 (only for panorama)
        
            {# Saving offset 2 #}
            this._iCompassOffset2 = this._iCompassDegrees;
            if(this._iCompassOffset2 > this._iCompassOffset1)   this._iCompassOffset2 -= 360;
            
            console.info("Plan rotation offset 2 is %o",this._iCompassOffset2);
            objM.updateFieldObj(this.id,"options.compass_offset2",this._iCompassOffset2);
            
            {# Finishing calibration #}
            this.compassEndCalibrate();
            
            break;
    }
}

this.compassEndCalibrate = function(){
    this.compassCalibrateShowHide(false);

    this._bCompassCalibrated = true;
    objM.updateFieldObj(this.id,"options.compass_calibrated",1);

    this._bCompassActive = true;
    objM.updateFieldObj(this.id,"options.compass_active",1);

    this.compassEnableDisable(true);
    
    themeManager.showMessage("{{getConstant('_DPAD_THEME_PLAN_COMPASS_CALIBRATE_DONE_MESSAGE')|encode4jscript}}","info",2);
}

this.compassCalibrateUpdateCaption = function(){

    var title =         rM.getConstant("_DPAD_THEME_PLAN_COMPASS_CALIBRATE_MODE"+this._iCompassMode+"_TITLE");
    var description =   rM.getConstant("_DPAD_THEME_PLAN_COMPASS_CALIBRATE_MODE"+this._iCompassMode+"_STEP"+this._iCompassCalibrateStep+"_INSTRUCTION");
    var notes =         rM.getConstant("_DPAD_THEME_PLAN_COMPASS_CALIBRATE_MODE"+this._iCompassMode+"_NOTES");
    
    this.compassCalibrate.find("#title").html(title);
    this.compassCalibrate.find("#description").html(description);
    this.compassCalibrate.find("#notes").html(notes);
    
    switch(this._iCompassMode){
        case 1:
            this.compassCalibrate.find("#floor").hide();
            this.compassCalibrate.find("#wall").show();
            
            switch(this._iCompassCalibrateStep){
                case 0:
                    this.compassCalibrate.find("#device").css("-webkit-transform","translate3d(-50px,0,0)");
                    this.compassCalibrate.find("#device").css("transform","translate3d(-50px,0,0)");
                    break;
                case 1:
                    this.compassCalibrate.find("#device").css("-webkit-transform","translate3d(50px,0,0)");
                    this.compassCalibrate.find("#device").css("transform","translate3d(50px,0,0)");
                    break;
            }
            break;
        case 0:
        default:
            this.compassCalibrate.find("#floor").show();
            this.compassCalibrate.find("#wall").hide();
            this.compassCalibrate.find("#device").css("-webkit-transform","translate3d(0px,0,0)");
            this.compassCalibrate.find("#device").css("transform","translate3d(0px,0,0)");
            break;
    }
}

{% endblock _customScope %}