#!/bin/bash
###############################################################################
#
#   Domuspad FSM Daemon Server.
#   Copyright (C) 2004 Domotica Labs. All Rights Reserved.
#   See http://www.domoticalabs.com/ for more information.
#
###############################################################################
#
#   description: Restore factory parameters script
#   parameters: none
#
###############################################################################
#                            CUSTOMIZABLE VARIABLES
###############################################################################
#
REMOUNTRW_SCRIPT=/usr/local/sbin/remountrw2
REMOUNTRO_SCRIPT=/usr/local/sbin/remountro2
FACTORY_DATABASE_FILE=/var/RWdlabs/dpadd/DomusPad.db-dist
FACTORY_DATABASE_FILE_TMP=/tmp/DomusPad.db-dist.lic
RUNNING_DATABASE_FILE=/var/RWdlabs/dpadd/DomusPad.db
RUNNING_ONLINE_DATABASE_FILE=/tmp/dpad_variables/db/DomusPad.db
FACTORY_DATABASE_FILE_TRK=/var/RWdlabs/dpadd/DomusPadTrack.db-dist
RUNNING_DATABASE_FILE_TRK=/var/RWdlabs/dpadd/DomusPadTrack.db
RUNNING_ONLINE_DATABASE_FILE_TRK=/tmp/dpad_variables/db/DomusPadTrack.db
DPADD_STOPSTART_SCRIPT=/etc/dpadd/dpadd.sh
SQL_PRODUCT_FILE_TMP=/tmp/prod.sql
SQL_MODULES_FILE_TMP=/tmp/mods.sql
#
###############################################################################
#                            FUNCTIONS
###############################################################################
#
create_licensed_database_file () {
 echo -n "update dpad_web_product set license='"> ${SQL_PRODUCT_FILE_TMP}
 echo -n `sqlite3 /etc/dpadd/DomusPad.db "select license from dpad_web_product where name='K3'"`>> ${SQL_PRODUCT_FILE_TMP}
 echo "' where name='K3';">> ${SQL_PRODUCT_FILE_TMP}
 echo -n "update dpad_web_module set license='"> ${SQL_MODULES_FILE_TMP}
 echo -n `sqlite3 /etc/dpadd/DomusPad.db "select license from dpad_web_module where name='system'"`>> ${SQL_MODULES_FILE_TMP}
 echo "' where name='system';">> ${SQL_MODULES_FILE_TMP}
 echo -n "update dpad_web_module set license='">> ${SQL_MODULES_FILE_TMP}
 echo -n `sqlite3 /etc/dpadd/DomusPad.db "select license from dpad_web_module where name='supervision'"`>> ${SQL_MODULES_FILE_TMP}
 echo "' where name='supervision';">> ${SQL_MODULES_FILE_TMP}
 echo -n "update dpad_web_module set license='">> ${SQL_MODULES_FILE_TMP}
 echo -n `sqlite3 /etc/dpadd/DomusPad.db "select license from dpad_web_module where name='camera'"`>> ${SQL_MODULES_FILE_TMP}
 echo "' where name='camera';">> ${SQL_MODULES_FILE_TMP}
 echo -n "update dpad_web_module set license='">> ${SQL_MODULES_FILE_TMP}
 echo -n `sqlite3 /etc/dpadd/DomusPad.db "select license from dpad_web_module where name='eib'"`>> ${SQL_MODULES_FILE_TMP}
 echo "' where name='eib';">> ${SQL_MODULES_FILE_TMP}
 echo -n "update dpad_web_module set license='">> ${SQL_MODULES_FILE_TMP}
 echo -n `sqlite3 /etc/dpadd/DomusPad.db "select license from dpad_web_module where name='konnect'"`>> ${SQL_MODULES_FILE_TMP}
 echo "' where name='konnect';">> ${SQL_MODULES_FILE_TMP}
 cp -pfr ${FACTORY_DATABASE_FILE} ${FACTORY_DATABASE_FILE_TMP}
 RETVAL=$?
 if [ ${RETVAL} -ne 0 ]
 then
  echo 11
  return 1
 fi
 sqlite3 ${FACTORY_DATABASE_FILE_TMP} ".read ${SQL_PRODUCT_FILE_TMP}"
 RETVAL=$?
 if [ ${RETVAL} -ne 0 ]
 then
  echo 12
  return 1
 fi
 sqlite3 ${FACTORY_DATABASE_FILE_TMP} ".read ${SQL_MODULES_FILE_TMP}"
 RETVAL=$?
 if [ ${RETVAL} -ne 0 ]
 then
  echo 13
  return 1
 fi
 echo 0
 return 0
}
#
###############################################################################
#                            START SCRIPT
###############################################################################
#
#Check if there is a factory defaults database file
if [ -e ${FACTORY_DATABASE_FILE} ]
then
 if [ -s ${FACTORY_DATABASE_FILE} ]
 then
  RETCODE=0
 else
  #Bad situation, do nothing because the software database is already corrupted
  exit 1
 fi
else
 #Bad situation, do nothing because the software database is already corrupted
 exit 2
fi
#Check if there is a running database file
if [ -e ${RUNNING_DATABASE_FILE} ]
then
 if [ -s ${RUNNING_DATABASE_FILE} ]
 then
  RETCODE=0
 else
  #Bad situation, do nothing because the software database is already corrupted
  exit 3
 fi
else
 #Bad situation, do nothing because the software database is already corrupted
 exit 4
fi
RETCODE=`create_licensed_database_file`
if [ ${RETCODE} -ne 0 ]
then
 #Something goes wrong while licensing factory database file
 exit 5
fi
#Stop the dpadd service
${DPADD_STOPSTART_SCRIPT} stop
#Remount filesystem read-write
${REMOUNTRW_SCRIPT}
#Copy the licensed factory database file to running one
cp -pfr ${FACTORY_DATABASE_FILE_TMP} ${RUNNING_DATABASE_FILE}
cp -pfr ${FACTORY_DATABASE_FILE_TMP} ${RUNNING_ONLINE_DATABASE_FILE}
cp -pfr ${FACTORY_DATABASE_FILE_TRK} ${RUNNING_DATABASE_FILE_TRK}
cp -pfr ${FACTORY_DATABASE_FILE_TRK} ${RUNNING_ONLINE_DATABASE_FILE_TRK}
#Remount filesystem read-only
${REMOUNTRO_SCRIPT}
#Restart the dpadd service
${DPADD_STOPSTART_SCRIPT} restart
exit 0
#
###############################################################################
#                            END SCRIPT
###############################################################################
