#!/bin/sh
###############################################################################
#
#   Domuspad FSM Daemon Server.
#   Copyright (C) 2004 Domotica Labs. All Rights Reserved.
#   See http://www.domoticalabs.com/ for more information.
#
###############################################################################
#
#   description: Startup/shutdown script for Domuspad FSM Daemon Server
#                tpuart version
#
#   under debian:
#   update-rc.d ohm start 99 2 3 4 5 . stop 10 0 1 6 .
#
#   under red-hat:
#   chkconfig: 2345 99 10
#   chkconfig --add dpadd
#
#   under FreeBSD:
#   just copy under /usr/local/etc/rc.d
#
#   version: 1.1
#
################################################################################
#                            CUSTOMIZABLE VARIABLES
################################################################################
#
. /etc/dpadd/dpadd.conf
. /etc/dpadd/dpaddrv.conf
. /lib/lsb/init-functions
#
# HERE STANDARD VARIABLE MAY BE OVERRIDDEN
BASENAME=dpadd
PIDFILE=/var/run/${BASENAME}.pid
LOCKDIR=/var/lock/subsys
LOGFILE=/var/log/DomusPad.log
SETSERIAL_CMD=/bin/setserial
SOURCEADDRFILE=/etc/dpadd/nameservice.conf
SOURCEADDR=0.0.255
EIBDPIDFILE=/var/run/eibd.pid
#
#################################################################################
#                            FIXED VARIABLES
#################################################################################
#
ECHONAME="Domuspad FSM Daemon Server"
LOCKFILE=${LOCKDIR}/${BASENAME}
OUT_SINK_EIBD=/dev/tty3
OUT_SINK_NOSTDOUT=/dev/tty2
#
#################################################################################
#                            START SCRIPT
#################################################################################
#
start() {
    RETCODE=OK
    if [ -f ${PIDFILE} ] && ps `cat ${PIDFILE}` > /dev/null
    then
     echo -n "Starting ${ECHONAME}: ${BASENAME}"
     log_end_msg 1
     echo "*** Service already running (normal mode) ***"
     return 1
    fi
    if [ -f ${LOGFILE} ] && [ -f ${PIDFILE} ]
    then
     WATCHDOG_ERROR=`tail ${LOGFILE} | grep \`cat ${PIDFILE}\` | awk 'BEGIN { FS = ":" }; { if( NR == 1 ) print \$5 }' | awk 'BEGIN { FS = " " }; { print \$6 }'`
     if [ ${WATCHDOG_ERROR} -eq 315 ]
     then
      echo -n "Starting ${ECHONAME}: ${BASENAME}"
      log_end_msg 1
      echo "*** Service already running (unlicensed mode) ***"
      return 1
     fi
    fi

    #setting the usage of LinuxThreads on the host system instead of NPTL threading model
    #
    # getconf GNU_LIBPTHREAD_VERSION to get the current threading model
    #
    #export LD_ASSUME_KERNEL=2.4.1
    # 
    # *** ERASED *** after EIBDriver release > 1.03.0014
    
    export EIBDRIVER_SEND_ACK=1
    export EIBDRIVER_LOWSPEED=0

    #setting the memory allocation debug
    #
    # 0 means no messages and no process fault on malloc failure
    # 1 means 
    # 2 means 
    # 3 means enable message output and process fault on malloc failure
    #
    #export MALLOC_CHECK_=3

    /etc/dpadd/dpadd_serial.sh start
    RETVAL=$?
    if [ ${RETVAL} -ne 0 ]
    then
     RETCODE=KO
     echo "*** Cannot build a valid license for this machine, the ${ECHONAME} will not start ***"
     return 1
    else
     RETCODE=OK
    fi
    /etc/dpadd/dpadd_serial.sh stop
    RETVAL=$?
    if [ ${RETVAL} -ne 0 ]
    then
     RETCODE=KO
     echo "*** Cannot build a valid license for this machine, the ${ECHONAME} will not start ***" 
     return 1
    else
     RETCODE=OK
    fi

    if [ ${DPAD_EIB_TPUART_LOAD_DISCHDRIVER} -eq 1 ]
    then
     if [ "$RETCODE" = "OK" ]
     then
      ${SETSERIAL_CMD} ${DPAD_EIB_TPUART_SERIALDEVICE} low_latency
      echo -n "Starting disch tpuart driver: NameServer"
      /usr/local/bin/NameServer ${DPAD_EIB_TPUART_PROJECTPATH} > $OUT_SINK 2>&1 &
      RETVAL=$?
      if [ ${RETVAL} -ne 0 ]
      then
       RETCODE=KO
       log_end_msg 1
      else
       RETCODE=OK
       log_end_msg 0
       sleep 1
      fi
     fi

     if [ "$RETCODE" = "OK" ]
     then
      echo -n "Starting disch tpuart driver: EIBDriver"
      /usr/local/bin/EIBDriver ${DPAD_EIB_TPUART_SERIALDEVICE} TP_UART_IC ${DPAD_EIB_TPUART_NAMESERVICEPATH} > $OUT_SINK 2>&1 &
      RETVAL=$?
      if [ ${RETVAL} -ne 0 ]
      then
       RETCODE=KO
       log_end_msg 1
      else
       RETCODE=OK
       log_end_msg 0
       sleep 1
      fi
     fi
    else if [ ${DPAD_EIB_TPUART_LOAD_EIBDDRIVER} -eq 1 ]
     then
      parse_nameservice_file 
      echo -n "Starting eibd tpuart driver: eibd"
      /usr/local/bin/eibd --eibaddr=${SOURCEADDR} --pid-file=${EIBDPIDFILE} -D -T -S -u tpuarts:${DPAD_EIB_TPUART_SERIALDEVICE} > $OUT_SINK_EIBD &
      RETVAL=$?
      if [ ${RETVAL} -ne 0 ]
      then
       RETCODE=KO
       log_end_msg 1
      else
       RETCODE=OK
       #set the interface socket accessible for any user
       sleep 2
       chmod 777 /tmp/eib
       log_end_msg 0
      fi
     fi
    fi
    ${BASEDIR}/${BASENAME} ${VERBOSE} -f ${CONFDIR}/${BASENAME}.conf > $OUT_SINK 2>&1
    RETVAL=$?
    if [ ${RETVAL} -ne 0 ]
    then
     RETCODE=KO
     sleep 5
    else
     sleep 3
     if [ -f ${PIDFILE} ] && ! ps `cat ${PIDFILE}` > /dev/null
     then
      echo "*** Service started but died prematurely. Tail syslog and messages for details ***"
      RETCODE=KO
      sleep 5
     fi
    fi
    [ "$RETCODE" = "OK" ] && [ -d ${LOCKDIR} ] && touch ${LOCKFILE}
    if [ "$RETCODE" = "OK" ]
    then
     echo -n "Starting ${ECHONAME}: ${BASENAME}"
     log_end_msg 0
     return 0
    else
     echo -n "Starting ${ECHONAME}: ${BASENAME}"
     log_end_msg 1
     return 1
    fi
}

stop() {
    RETCODE=KO
    if [ -f ${PIDFILE} ]
    then
     /bin/kill -SIGTERM `cat ${PIDFILE}` > /dev/null 
     RETVAL=$?
     if [ ${RETVAL} -ne 0 ]
     then
      RETCODE=KO
      sleep 1
     else
      RETCODE=OK
      sleep 1
     fi
    else
     echo "*** Service is not running ***"
    fi
    sleep 1
    if [ -f ${PIDFILE} ]
    then
     rm -f ${PIDFILE}
    fi  
    [ "${RETCODE}" = "OK" ] && [ -d ${LOCKDIR} ] && rm -f ${LOCKFILE}
    if [ "${RETCODE}" = "OK" ]
    then
     echo -n "Stopping ${ECHONAME}: ${BASENAME}"
     log_end_msg 0
     RETVAL=0
    else
     echo -n "Stopping ${ECHONAME}: ${BASENAME}"
     log_end_msg 1
     RETVAL=1
    fi

    if [ ${DPAD_EIB_TPUART_LOAD_DISCHDRIVER} -eq 1 ]
    then
     echo -n "Stopping disch tpuart driver: EIBDriver"
     killall -qw -TERM EIBDriver > /dev/null 2>&1
     EDRETVAL=$?
     if [ ${EDRETVAL} -ne 0 ]
     then
      sleep 1
      log_end_msg 1
     else
      sleep 1
      log_end_msg 0
     fi

     echo -n "Stopping disch tpuart driver: NameServer"
     killall -qw -TERM NameServer > /dev/null 2>&1
     NSRETVAL=$?
     if [ ${NSRETVAL} -ne 0 ]
     then
      sleep 1
      log_end_msg 1
     else
      sleep 1
      log_end_msg 0
     fi
    else if [ ${DPAD_EIB_TPUART_LOAD_EIBDDRIVER} -eq 1 ]
     then
      echo -n "Stopping eibd tpuart driver: eibd"
      if [ -f ${EIBDPIDFILE} ]
      then
       /bin/kill -SIGKILL `cat ${EIBDPIDFILE}` > /dev/null
       EIBDRETVAL=$?
      else
       EIBDRETVAL=1
      fi
      if [ ${EIBDRETVAL} -ne 0 ]
      then
       sleep 1
       log_end_msg 1
      else
       sleep 1
       log_end_msg 0
      fi
      if [ -f ${EIBDPIDFILE} ]
      then
       rm -f ${EIBDPIDFILE}
      fi
      /usr/local/bin/eibdkillall.sh > /dev/null &
     fi
    fi

    /usr/local/bin/dpaddkillall.sh > /dev/null &

    return ${RETVAL}

}

restart() {
  stop
  sleep 1
  start
}

safestart() {
  # Setting OUT_SINK variable to fixed value
  OUT_SINK=${OUT_SINK_NOSTDOUT}
  start
}

saferestart() {
  stop
  sleep 1
  safestart
}

parse_nameservice_file() {
  RETCODE=OK
  if [ -f ${SOURCEADDRFILE} ]
  then
     if [ -r ${SOURCEADDRFILE} ]
     then
       echo "Parsing ${SOURCEADDRFILE}"
       N1=`cat ${SOURCEADDRFILE} | grep -i EIB_HW_ADDRESS | sed -e 's/[^=]*=//' -e 's/^\(.\)\(.\)\(.\)\(.\)$/\1/'`
       N2=`cat ${SOURCEADDRFILE} | grep -i EIB_HW_ADDRESS | sed -e 's/[^=]*=//' -e 's/^\(.\)\(.\)\(.\)\(.\)$/\2/'`
       N3=`cat ${SOURCEADDRFILE} | grep -i EIB_HW_ADDRESS | sed -e 's/[^=]*=//' -e 's/^\(.\)\(.\)\(.\)\(.\)$/\3\4/'`

       N1DEC=`printf '%d' 0x$N1`
       N2DEC=`printf '%d' 0x$N2`
       N3DEC=`printf '%d' 0x$N3`

       SOURCEADDR="$N1DEC.$N2DEC.$N3DEC"

       echo "Source address $SOURCEADDR"
     fi
  fi 
}

#################################################################################
#                            MAIN SCRIPT
#################################################################################

RETCODE=OK

case "$1" in
  start)
    start
    RETVAL=$?
    ;;

  stop)
    stop
    RETVAL=$?
    ;;

  restart)
    restart
    RETVAL=$?
    ;;

  safestart)
    safestart
    RETVAL=$?
    ;;

  saferestart)
    saferestart
    RETVAL=$?
    ;;

  *)
    echo "Usage: `basename $0` {start|stop|restart|safestart|saferestart}"
    RETVAL=1
    ;;

esac
exit $RETVAL

#################################################################################
#                            END SCRIPT
#################################################################################
