#!/bin/sh
###############################################################################
#
#   Domuspad FSM Daemon Server.
#   Copyright (C) 2004 Domotica Labs. All Rights Reserved.
#   See http://www.domoticalabs.com/ for more information.
#
###############################################################################
#
#   description: Startup/shutdown script for emaild Daemon Server
#
#   under debian:
#   update-rc.d ohm start 96 2 3 4 5 . stop 14 0 1 6 .
#
#   under red-hat:
#   chkconfig: 2345 96 14
#   chkconfig --add ohm
#
#   under FreeBSD:
#   just copy under /usr/local/etc/rc.d
#
#   version: 1.0
#
################################################################################
#                            CUSTOMIZABLE VARIABLES
################################################################################
#
. /etc/dpadd/emaild.conf
. /lib/lsb/init-functions
#
# HERE STANDARD VARIABLE MAY BE OVERRIDDEN
BASENAME=emaild
PIDFILE=/var/run/${BASENAME}.pid
LOCKDIR=/var/lock/subsys
#
#################################################################################
#                            FIXED VARIABLES
#################################################################################
#
ECHONAME="email Daemon Server"
LOCKFILE=${LOCKDIR}/${BASENAME}
LOGGER_CMD="/usr/bin/logger -i -p local7.info -t emaild.sh "
#
#################################################################################
#                            RUNTIME VARIABLES
#################################################################################
#
DAEMONPID=0
#
#################################################################################
#                            START SCRIPT
#################################################################################
#
daemon() {
 #Create email spooling directory if not exists
 ${LOGGER_CMD} "Start emaild daemon execution"
 if [ ! -d ${SPOOLDIR} ]
 then
  ${LOGGER_CMD} "Create the spooler directory..."
  mkdir ${SPOOLDIR}
  chmod 777 ${SPOOLDIR}
  ${LOGGER_CMD} "created!"
 fi
 while true
 do
  #Check for email generated by dpadd events
  for i in `ls ${SRCDIR}`
  do
   #Pick up them into spooler directory, if any excluding "last_sent_email"
   if [ "$i" != "last_sent_email" ]
   then
    mv ${SRCDIR}/$i ${SPOOLDIR}
   fi
  done
  for j in `ls ${SPOOLDIR}`
  do
   #Send emails througth php script, if any
   ${LOGGER_CMD} "Sending email ${SPOOLDIR}/$j..."
   ${SPOOLCMD} ${SPOOLDIR}/$j ${SPOOLSENDER}
   sleep 1
   ${LOGGER_CMD} "sent!"
  done
  #Going sleep
  sleep 5
 done
}

start() {
    RETCODE=OK
    if [ -f ${PIDFILE} ] && ps `cat ${PIDFILE}` > /dev/null
    then
     echo -n "Starting ${ECHONAME}: ${BASENAME}"
     log_end_msg 1
     echo "*** Service already running (normal mode) ***"
     return 1
    fi
    daemon &
    RETVAL=$?
    echo $! > ${PIDFILE}
    if [ ${RETVAL} -ne 0 ]
    then
     RETCODE=KO
     sleep 1
    else
     sleep 1
     if [ -f ${PIDFILE} ] && ! ps `cat ${PIDFILE}` > /dev/null
     then
      echo "*** Service started but died prematurely. Tail syslog and messages for details ***"
      RETCODE=KO
      sleep 1
     fi
    fi
    [ "$RETCODE" = "OK" ] && [ -d ${LOCKDIR} ] && touch ${LOCKFILE}
    if [ "$RETCODE" = "OK" ]
    then
     echo -n "Starting ${ECHONAME}: ${BASENAME}"
     log_end_msg 0
     return 0
    else
     echo -n "Starting ${ECHONAME}: ${BASENAME}"
     log_end_msg 1
     return 1
    fi
}

stop() {
    RETCODE=KO
    if [ -f ${PIDFILE} ]
    then
     /bin/kill -SIGTERM `cat ${PIDFILE}` > /dev/null
     RETCODE=OK
    else
     echo "*** Service is not running ***"
    fi
    sleep 1
    if [ -f ${PIDFILE} ]
    then
     rm -f ${PIDFILE}
    fi
    [ "${RETCODE}" = "OK" ] && [ -d ${LOCKDIR} ] && rm -f ${LOCKFILE}
    if [ "${RETCODE}" = "OK" ]
    then
     echo -n "Stopping ${ECHONAME}: ${BASENAME}"
     log_end_msg 0
     RETVAL=0
    else
     echo -n "Stopping ${ECHONAME}: ${BASENAME}"
     log_end_msg 1
     RETVAL=1
    fi
    return ${RETVAL}
}

restart() {
  stop
  sleep 1
  start
}

#################################################################################
#                            MAIN SCRIPT
#################################################################################

RETCODE=OK

case "$1" in
  start)
    start
    RETVAL=$?
    ;;

  stop)
    stop
    RETVAL=$?
    ;;

  restart)
    restart
    RETVAL=$?
    ;;

  *)
    echo "Usage: `basename $0` {start|stop|restart}"
    RETVAL=1
    ;;

esac
exit $RETVAL

#################################################################################
#                            END SCRIPT
#################################################################################
