#!/bin/bash
###############################################################################
#
#   Domuspad FSM Daemon Server.
#   Copyright (C) 2004 Domotica Labs. All Rights Reserved.
#   See http://www.domoticalabs.com/ for more information.
#
###############################################################################
#
#   description: Restore factory parameters script
#   parameters: none
#   version: 1.3
#
###############################################################################
#                            CUSTOMIZABLE VARIABLES
###############################################################################
#
REMOUNTRW_SCRIPT=/usr/local/sbin/remountrw2
REMOUNTRO_SCRIPT=/usr/local/sbin/remountro2
FACTORY_DATABASE_FILE=/var/RWdlabs/dpadd/DomusPad.db-dist
FACTORY_DATABASE_FILE_TMP=/tmp/DomusPad.db-dist.lic
RUNNING_DATABASE_FILE=/var/RWdlabs/dpadd/DomusPad.db
RUNNING_ONLINE_DATABASE_FILE=/tmp/dpad_variables/db/DomusPad.db
FACTORY_DATABASE_FILE_TRK=/var/RWdlabs/dpadd/DomusPadTrack.db-dist
RUNNING_DATABASE_FILE_TRK=/var/RWdlabs/dpadd/DomusPadTrack.db
RUNNING_ONLINE_DATABASE_FILE_TRK=/tmp/dpad_variables/db/DomusPadTrack.db
DPADD_STOPSTART_SCRIPT=/etc/dpadd/dpadd.sh
SQL_PRODUCT_FILE_TMP=/tmp/prod.sql
SQL_MODULES_FILE_TMP=/tmp/mods.sql
SQL_MODULES_LICENSE_FILE_TMP=/tmp/modlic.tmp
FACTORY_PROXY_FILE=/var/RWdlabs/network/proxies.conf.dlabs
FACTORY_PROXY_FILE_TMP=/tmp/proxies.conf.dlabs
RUNNING_PROXY_FILE=/var/RWdlabs/network/proxies.conf
RUNNING_PROXY_FILE_ONLINE=/tmp/RWdlabs/network/proxies.conf
#
###############################################################################
#                            FUNCTIONS
###############################################################################
#
create_licensed_database_file () {
 echo -n "update dpad_web_product set license='"> ${SQL_PRODUCT_FILE_TMP}
 echo -n `sqlite3 /etc/dpadd/DomusPad.db "select license from dpad_web_product where name='K3'"`>> ${SQL_PRODUCT_FILE_TMP}
 echo "' where name='K3';">> ${SQL_PRODUCT_FILE_TMP}
 echo -n ""> ${SQL_MODULES_FILE_TMP}
 sqlite3 /etc/dpadd/DomusPad.db "select name,license from dpad_web_module where license<>''"> ${SQL_MODULES_LICENSE_FILE_TMP}
 while read line
 do
  modulename=`echo $line | awk 'BEGIN { FS = "|" }; { print $1 }'`
  modulelicense=`echo $line | awk 'BEGIN { FS = "|" }; { print $2 }'`
  echo "update dpad_web_module set license='$modulelicense' where name='$modulename';">> ${SQL_MODULES_FILE_TMP}
 done < ${SQL_MODULES_LICENSE_FILE_TMP}
 cp -pfr ${FACTORY_DATABASE_FILE} ${FACTORY_DATABASE_FILE_TMP}
 RETVAL=$?
 if [ ${RETVAL} -ne 0 ]
 then
  echo 11
  return 1
 fi
 sqlite3 ${FACTORY_DATABASE_FILE_TMP} ".read ${SQL_PRODUCT_FILE_TMP}"
 RETVAL=$?
 if [ ${RETVAL} -ne 0 ]
 then
  echo 12
  return 1
 fi
 sqlite3 ${FACTORY_DATABASE_FILE_TMP} ".read ${SQL_MODULES_FILE_TMP}"
 RETVAL=$?
 if [ ${RETVAL} -ne 0 ]
 then
  echo 13
  return 1
 fi
 echo 0
 return 0
}

create_nginx_proxy_factory_file () {
 #Rewrite from scratch the following file
 
  #>>>
  
  ##############################################################################
  # Domotica Labs
  #
  # Nginx custom software proxies
  ##############################################################################
 
  
  #<<<
   
  echo "##############################################################################" > ${FACTORY_PROXY_FILE_TMP}
  echo "# Domotica Labs" >> ${FACTORY_PROXY_FILE_TMP}
  echo "#" >> ${FACTORY_PROXY_FILE_TMP}
  echo "# Nginx custom software proxies" >> ${FACTORY_PROXY_FILE_TMP}
  echo "##############################################################################" >> ${FACTORY_PROXY_FILE_TMP}
  echo "" >> ${FACTORY_PROXY_FILE_TMP}
  chmod 664 ${FACTORY_PROXY_FILE_TMP}
  chown root:dlabusers ${FACTORY_PROXY_FILE_TMP}
  echo ${FACTORY_PROXY_FILE_TMP}
  return 0
}
#
###############################################################################
#                            START SCRIPT
###############################################################################
#
#Check if there is a factory defaults database file
if [ -e ${FACTORY_DATABASE_FILE} ]
then
 if [ -s ${FACTORY_DATABASE_FILE} ]
 then
  RETCODE=0
 else
  #Bad situation, do nothing because the software database is already corrupted
  exit 1
 fi
else
 #Bad situation, do nothing because the software database is already corrupted
 exit 2
fi
#Check if there is a running database file
if [ -e ${RUNNING_DATABASE_FILE} ]
then
 if [ -s ${RUNNING_DATABASE_FILE} ]
 then
  RETCODE=0
 else
  #Bad situation, do nothing because the software database is already corrupted
  exit 3
 fi
else
 #Bad situation, do nothing because the software database is already corrupted
 exit 4
fi
RETCODE=`create_licensed_database_file`
if [ ${RETCODE} -ne 0 ]
then
 #Something goes wrong while licensing factory database file
 exit 5
fi
#Stop the dpadd service
${DPADD_STOPSTART_SCRIPT} stop
#Remount filesystem read-write
${REMOUNTRW_SCRIPT}
#Copy the licensed factory database file to running one
cp -pfr ${FACTORY_DATABASE_FILE_TMP} ${RUNNING_DATABASE_FILE}
cp -pfr ${FACTORY_DATABASE_FILE_TMP} ${RUNNING_ONLINE_DATABASE_FILE}
cp -pfr ${FACTORY_DATABASE_FILE_TRK} ${RUNNING_DATABASE_FILE_TRK}
cp -pfr ${FACTORY_DATABASE_FILE_TRK} ${RUNNING_ONLINE_DATABASE_FILE_TRK}
#Remount filesystem read-only
${REMOUNTRO_SCRIPT}
#Restart the dpadd service
${DPADD_STOPSTART_SCRIPT} restart
#Check if there is a factory defaults ip address file
if [ -e ${FACTORY_PROXY_FILE} ]
then
 if [ -s ${FACTORY_PROXY_FILE} ]
 then
  RETCODE=0
 else
  #Populate a new one
  FACTORY_PROXY_FILE=`create_nginx_proxy_factory_file`
 fi
else
 #Populate a new one
 FACTORY_PROXY_FILE=`create_nginx_proxy_factory_file`
fi
#Remount filesystem read-write
${REMOUNTRW_SCRIPT}
#Copy the factory file to running one
cp -pfr ${FACTORY_PROXY_FILE} ${RUNNING_PROXY_FILE}
cp -pfr ${FACTORY_PROXY_FILE} ${RUNNING_PROXY_FILE_ONLINE}
#Remount filesystem read-only
${REMOUNTRO_SCRIPT}
#Restart nginx infrastructure
/etc/init.d/nginx restart 2>/dev/null
exit 0
#
###############################################################################
#                            END SCRIPT
###############################################################################
