/*
Flot plugin for showing crosshairs, thin lines, when the mouse hovers
over the plot.

  crosshair: {
    mode: null or "x" or "y" or "xy"
    color: color
    lineWidth: number
  }

Set the mode to one of "x", "y" or "xy". The "x" mode enables a
vertical crosshair that lets you trace the values on the x axis, "y"
enables a horizontal crosshair and "xy" enables them both. "color" is
the color of the crosshair (default is "rgba(170, 0, 0, 0.80)"),
"lineWidth" is the width of the drawn lines (default is 1).

The plugin also adds four public methods:

  - setCrosshair(pos)

    Set the position of the crosshair. Note that this is cleared if
    the user moves the mouse. "pos" is in coordinates of the plot and
    should be on the form { x: xpos, y: ypos } (you can use x2/x3/...
    if you're using multiple axes), which is coincidentally the same
    format as what you get from a "plothover" event. If "pos" is null,
    the crosshair is cleared.

  - clearCrosshair()

    Clear the crosshair.

  - lockCrosshair(pos)

    Cause the crosshair to lock to the current location, no longer
    updating if the user moves the mouse. Optionally supply a position
    (passed on to setCrosshair()) to move it to.

    Example usage:
      var myFlot = $.plot( $("#graph"), ..., { crosshair: { mode: "x" } } };
      $("#graph").bind("plothover", function (evt, position, item) {
        if (item) {
          // Lock the crosshair to the data point being hovered
          myFlot.lockCrosshair({ x: item.datapoint[0], y: item.datapoint[1] });
        }
        else {
          // Return normal crosshair operation
          myFlot.unlockCrosshair();
        }
      });

  - unlockCrosshair()

    Free the crosshair to move again after locking it.
*/(function(a){function c(a){function c(c){if(b.locked)return;b.x!=-1&&(b.x=-1,a.triggerRedrawOverlay())}function d(c){if(b.locked)return;if(a.getSelection&&a.getSelection()){b.x=-1;return}var d=a.offset();b.x=Math.max(0,Math.min(c.pageX-d.left,a.width())),b.y=Math.max(0,Math.min(c.pageY-d.top,a.height())),a.triggerRedrawOverlay()}var b={x:-1,y:-1,locked:!1};a.setCrosshair=function(d){if(!d)b.x=-1;else{var e=a.p2c(d);b.x=Math.max(0,Math.min(e.left,a.width())),b.y=Math.max(0,Math.min(e.top,a.height()))}a.triggerRedrawOverlay()},a.clearCrosshair=a.setCrosshair,a.lockCrosshair=function(d){d&&a.setCrosshair(d),b.locked=!0},a.unlockCrosshair=function(){b.locked=!1},a.hooks.bindEvents.push(function(a,b){if(!a.getOptions().crosshair.mode)return;b.mouseout(c),b.mousemove(d)}),a.hooks.drawOverlay.push(function(a,c){var d=a.getOptions().crosshair;if(!d.mode)return;var e=a.getPlotOffset();c.save(),c.translate(e.left,e.top),b.x!=-1&&(c.strokeStyle=d.color,c.lineWidth=d.lineWidth,c.lineJoin="round",c.beginPath(),d.mode.indexOf("x")!=-1&&(c.moveTo(b.x,0),c.lineTo(b.x,a.height())),d.mode.indexOf("y")!=-1&&(c.moveTo(0,b.y),c.lineTo(a.width(),b.y)),c.stroke()),c.restore()}),a.hooks.shutdown.push(function(a,b){b.unbind("mouseout",c),b.unbind("mousemove",d)})}var b={crosshair:{mode:null,color:"rgba(170, 0, 0, 0.80)",lineWidth:1}};a.plot.plugins.push({init:c,options:b,name:"crosshair",version:"1.0"})})(jQuery);