/*
Flot plugin for stacking data sets, i.e. putting them on top of each
other, for accumulative graphs.

The plugin assumes the data is sorted on x (or y if stacking
horizontally). For line charts, it is assumed that if a line has an
undefined gap (from a null point), then the line above it should have
the same gap - insert zeros instead of "null" if you want another
behaviour. This also holds for the start and end of the chart. Note
that stacking a mix of positive and negative values in most instances
doesn't make sense (so it looks weird).

Two or more series are stacked when their "stack" attribute is set to
the same key (which can be any number or string or just "true"). To
specify the default stack, you can set

  series: {
    stack: null or true or key (number/string)
  }

or specify it for a specific series

  $.plot($("#placeholder"), [{ data: [ ... ], stack: true }])
  
The stacking order is determined by the order of the data series in
the array (later series end up on top of the previous).

Internally, the plugin modifies the datapoints in each series, adding
an offset to the y value. For line series, extra data points are
inserted through interpolation. If there's a second y value, it's also
adjusted (e.g for bar charts or filled areas).
*/(function(a){function c(a){function b(a,b){var c=null;for(var d=0;d<b.length;++d){if(a==b[d])break;b[d].stack==a.stack&&(c=b[d])}return c}function c(a,c,d){if(c.stack==null)return;var e=b(c,a.getData());if(!e)return;var f=d.pointsize,g=d.points,h=e.datapoints.pointsize,i=e.datapoints.points,j=[],k,l,n,o,p,q,r=c.lines.show,s=c.bars.horizontal,t=f>2&&(s?d.format[2].x:d.format[2].y),u=r&&c.lines.steps,v=!0,w=s?1:0,x=s?0:1,y=0,z=0,A;for(;;){if(y>=g.length)break;A=j.length;if(g[y]==null){for(m=0;m<f;++m)j.push(g[y+m]);y+=f}else if(z>=i.length){if(!r)for(m=0;m<f;++m)j.push(g[y+m]);y+=f}else if(i[z]==null){for(m=0;m<f;++m)j.push(null);v=!0,z+=h}else{k=g[y+w],l=g[y+x],o=i[z+w],p=i[z+x],q=0;if(k==o){for(m=0;m<f;++m)j.push(g[y+m]);j[A+x]+=p,q=p,y+=f,z+=h}else if(k>o){if(r&&y>0&&g[y-f]!=null){n=l+(g[y-f+x]-l)*(o-k)/(g[y-f+w]-k),j.push(o),j.push(n+p);for(m=2;m<f;++m)j.push(g[y+m]);q=p}z+=h}else{if(v&&r){y+=f;continue}for(m=0;m<f;++m)j.push(g[y+m]);r&&z>0&&i[z-h]!=null&&(q=p+(i[z-h+x]-p)*(k-o)/(i[z-h+w]-o)),j[A+x]+=q,y+=f}v=!1,A!=j.length&&t&&(j[A+2]+=q)}if(u&&A!=j.length&&A>0&&j[A]!=null&&j[A]!=j[A-f]&&j[A+1]!=j[A-f+1]){for(m=0;m<f;++m)j[A+f+m]=j[A+m];j[A+1]=j[A-f+1]}}d.points=j}a.hooks.processDatapoints.push(c)}var b={series:{stack:null}};a.plot.plugins.push({init:c,options:b,name:"stack",version:"1.2"})})(jQuery);