--Module: VIVALDI

--Creating Vivaldi configuration table
CREATE TABLE DPAD_VIVALDI_CONFIGURATION( ID INTEGER PRIMARY KEY AUTOINCREMENT, NAME TEXT, VALUE TEXT, DESCRIPTION TEXT, SECTION_ID INTEGER DEFAULT -1);

--Creating views for object access
CREATE VIEW DPAD_VIVALDIGATEWAY_VIVALDIZONES AS SELECT O.ID AS ID, O.MSP AS RCID, RO.PARENTOBJ_ID AS CENTRALID , O.COMMUNICATIONSECTION_ID AS COMMUNICATIONSECTION_ID FROM DPADD_OBJECT O, DPADD_OBJECT_RELATION RO WHERE O.TYPE = 'VIVALDI_RC20' AND O.ID = RO.CHILDOBJ_ID AND RO.RELATION_WEB_TIPOLOGY= 'VIVALDI_CENTRAL_RELATION';
CREATE VIEW DPAD_VIVALDIGATEWAY_VIVALDICONTROLS AS SELECT O.ID AS ID, RO.PARENTOBJ_ID AS RCID, O.TYPE AS TIPOLOGY FROM DPADD_OBJECT O, DPADD_OBJECT_RELATION RO WHERE ( (O.TYPE = 'VIVALDI_ONOFF') OR (O.TYPE = 'VIVALDI_VOLUME') OR (O.TYPE = 'VIVALDI_CHANNEL') OR (O.TYPE = 'VIVALDI_HIGH') OR (O.TYPE = 'VIVALDI_LOW') OR (O.TYPE = 'VIVALDI_CD') OR (O.TYPE = 'VIVALDI_TRACK') OR (O.TYPE = 'VIVALDI_TUNER') ) AND O.ID = RO.CHILDOBJ_ID AND RO.RELATION_WEB_TIPOLOGY= 'VIVALDI_RC_RELATION';

--Adding FSM settings
INSERT INTO DPAD_FSM_CONFIGURATION (NAME, VALUE, DESCRIPTION) VALUES ('DPAD_VIVALDICONF_TABLE', 'DPAD_VIVALDI_CONFIGURATION', 'Table of VIVALDI configuration properties');
INSERT INTO DPAD_FSM_CONFIGURATION (NAME, VALUE, DESCRIPTION) VALUES ('DPAD_VIVALDICOMMAND_SOCKET_FILE', '/tmp/dpad_variables/sockets/dpad_vivaldigateway.socket', 'Unix socket for low-level vivaldigateway service communication');
INSERT INTO DPAD_FSM_CONFIGURATION (NAME, VALUE, DESCRIPTION) VALUES ('DPAD_VIVALDILOOP_TIMEOUT', '500000', 'Vivaldi main loop idle timeout');

--Vivaldi Central
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiCentral', 'vivaldi', 'dpadvivaldicentral.class.php', 'dpadCommunicationSection', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDICENTRAL', 'vivaldi_central.png', '', '', '', '1', '0', '0' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_CENTRAL", "_DPAD_DBCONSTANT_TYPE_VIVALDI_CENTRAL", "dpadVivaldiCentral", "" );
--Vivaldi Command Rc 20 Object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiCommandRc20', 'vivaldi', 'dpadvivaldicommandrc20.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDICOMMANDRC20', 'vivaldi_rc_command_20.png', '', '', '', '1', '0', '0' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_RC20", "_DPAD_DBCONSTANT_TYPE_VIVALDI_COMMANDRC20", "dpadVivaldiCommandRc20", "" );
--Vivaldi Volume Object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiVolume', 'vivaldi', 'dpadvivaldivolume.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDIVOLUME', 'vivaldi_volume.png', '', '', '', '1', '1', '1' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_VOLUME", "_DPAD_DBCONSTANT_TYPE_VIVALDI_VOLUME", "dpadVivaldiVolume", "SETVALUE" );
--Vivaldi Channel Object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiChannel', 'vivaldi', 'dpadvivaldichannel.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDICHANNEL', 'vivaldi_channel.png', '', '', '', '1', '1', '1' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_CHANNEL", "_DPAD_DBCONSTANT_TYPE_VIVALDI_CHANNEL", "dpadVivaldiChannel", "SETVALUE" );
--Vivaldi Low Object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiLow', 'vivaldi', 'dpadvivaldilow.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDILOW', 'vivaldi_low.png', '', '', '', '1', '1', '1' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_LOW", "_DPAD_DBCONSTANT_TYPE_VIVALDI_LOW", "dpadVivaldiLow", "SETVALUE" );
--Vivaldi High Object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiHigh', 'vivaldi', 'dpadvivaldihigh.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDIHIGH', 'vivaldi_high.png', '', '', '', '1', '1', '1' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_HIGH", "_DPAD_DBCONSTANT_TYPE_VIVALDI_HIGH", "dpadVivaldiHigh", "SETVALUE" );
--Vivaldi On/Off Object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiOnOff', 'vivaldi', 'dpadvivaldionoff.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDIONOFF', 'vivaldi_onoff.png', '', '', '', '1', '1', '1' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_ONOFF", "_DPAD_DBCONSTANT_TYPE_VIVALDI_ONOFF", "dpadVivaldiOnOff", "SETVALUE" );
--Vivaldi Tuner Object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiTuner', 'vivaldi', 'dpadvivaldituner.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDITUNER', 'vivaldi_tuner.png', '', '', '', '1', '1', '1' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_TUNER", "_DPAD_DBCONSTANT_TYPE_VIVALDI_TUNER", "dpadVivaldiTuner", "SETVALUE" );
--Vivaldi CD object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiCd', 'vivaldi', 'dpadvivaldicd.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDICD', 'vivaldi_cd.png', '', '', '', '1', '1', '1' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_CD", "_DPAD_DBCONSTANT_TYPE_VIVALDI_CD", "dpadVivaldiCd", "SETVALUE" );
--Vivaldi Track Object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiTrack', 'vivaldi', 'dpadvivalditrack.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDITRACK', 'vivaldi_track.png', '', '', '', '1', '1', '1' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_TRACK", "_DPAD_DBCONSTANT_TYPE_VIVALDI_TRACK", "dpadVivaldiTrack", "SETVALUE" );
--Vivaldi Scene Object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiScene', 'vivaldi', 'dpadvivaldiscene.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDISCENE', 'vivaldi_scene.png', '', '', '', '1', '1', '0' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_SCENE", "_DPAD_DBCONSTANT_TYPE_VIVALDI_SCENE", "dpadVivaldiScene", "SETVALUE" );
--Vivaldi Ircode Object
INSERT INTO "DPAD_WEB_PHPCLASS" ( ID, CLASSNAME, MODULE, INCLUDE_PATH, PARENTCLASS, NAME, IMAGE_PATH, VIEWOBJPATH, EDITOBJPATH, DETAILSOBJPATH, IS_VISIBLE, IS_EXECUTABLE, IS_EVENT ) VALUES( NULL, 'dpadVivaldiIrcode', 'vivaldi', 'dpadvivaldiircode.class.php', 'dpadObject', '_DPAD_DBCONSTANT_WEBPHPCLASS_DPADVIVALDIIRCODE', 'vivaldi_ircode.png', '', '', '', '1', '1', '0' );
INSERT INTO "DPADD_OBJECT_TYPES" ( ID, TYPE, DESCRIPTION, PHPCLASS, ALLOWED_ACTIONS ) VALUES ( NULL, "VIVALDI_IRCODE", "_DPAD_DBCONSTANT_TYPE_VIVALDI_IRCODE", "dpadVivaldiIrcode", "SETVALUE" );

--Updating actions for specific types
UPDATE "DPADD_OBJECT_TYPES" SET ALLOWED_ACTIONS='PLAY|RECORD' WHERE PHPCLASS='dpadVivaldiScene';
UPDATE "DPADD_OBJECT_TYPES" SET ALLOWED_ACTIONS='PLAY|RECORD' WHERE PHPCLASS='dpadVivaldiIrcode';
UPDATE "DPADD_OBJECT_TYPES" SET ALLOWED_ACTIONS='NEXT|PREV' WHERE PHPCLASS='dpadVivaldiCd';
UPDATE "DPADD_OBJECT_TYPES" SET ALLOWED_ACTIONS='NEXT|PREV' WHERE PHPCLASS='dpadVivaldiTrack';
UPDATE "DPADD_OBJECT_TYPES" SET ALLOWED_ACTIONS='SETVALUE|INCREASE|DECREASE' WHERE PHPCLASS='dpadVivaldiVolume';
UPDATE "DPADD_OBJECT_TYPES" SET ALLOWED_ACTIONS='SETVALUE|INCREASE|DECREASE' WHERE PHPCLASS='dpadVivaldiHigh';
UPDATE "DPADD_OBJECT_TYPES" SET ALLOWED_ACTIONS='SETVALUE|INCREASE|DECREASE' WHERE PHPCLASS='dpadVivaldiLow';
UPDATE "DPADD_OBJECT_TYPES" SET ALLOWED_ACTIONS='SETVALUE|INCREASE|DECREASE' WHERE PHPCLASS='dpadVivaldiChannel';
UPDATE "DPADD_OBJECT_TYPES" SET ALLOWED_ACTIONS='SETVALUE|INCREASE|DECREASE' WHERE PHPCLASS='dpadVivaldiTuner';

--Vivaldi Renderings
-- $VIVALDI_RENDERING_CENTRAL$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_CENTRAL', 1, '0', '1', '1', 'ico_vivaldi_central_ok.png', '0=>"_DPAD_DBCONSTANT_RENDERING_VIVALDI_CENTRAL_OK",1=>"_DPAD_DBCONSTANT_RENDERING_VIVALDI_CENTRAL_KO"', '0=>"ico_vivaldi_central_ok.png",1=>"ico_vivaldi_central_ko.png"', '', '', '', 'dpadVivaldiCentral ', '');
-- $VIVALDI_RENDERING_RC20$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_RC20', 0, '', '', '', 'ico_vivaldi_rc20.png', '', '', '', '', '', 'dpadVivaldiCommandRc20 ', '');
-- $VIVALDI_RENDERING_ONOFF$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_ON_OFF', 1, '0', '1', '1', 'ico_audio_generic_on.png', '0=>"_DPAD_DBCONSTANT_RENDERING_OFF",1=>"_DPAD_DBCONSTANT_RENDERING_ON"', '0=>"ico_audio_generic_off.png",1=>"ico_audio_generic_on.png"', '0=>"button_label_O.png",1=>"button_label_I.png"', '', '', 'dpadVivaldiOnOff ', '');
-- $VIVALDI_RENDERING_VOLUME$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_VOLUME', 1, '0', '100', '5', 'ico_audio_generic_on.png', '0=>"_DPAD_DBCONSTANT_RENDERING_0_PERC",10=>"_DPAD_DBCONSTANT_RENDERING_10_PERC",20=>"_DPAD_DBCONSTANT_RENDERING_20_PERC",30=>"_DPAD_DBCONSTANT_RENDERING_30_PERC",40=>"_DPAD_DBCONSTANT_RENDERING_40_PERC",50=>"_DPAD_DBCONSTANT_RENDERING_50_PERC",60=>"_DPAD_DBCONSTANT_RENDERING_60_PERC",70=>"_DPAD_DBCONSTANT_RENDERING_70_PERC",80=>"_DPAD_DBCONSTANT_RENDERING_80_PERC",90=>"_DPAD_DBCONSTANT_RENDERING_90_PERC",100=>"_DPAD_DBCONSTANT_RENDERING_100_PERC', '0=>"ico_percent_0.png",10=>"ico_percent_10.png",20=>"ico_percent_20.png",30=>"ico_percent_30.png",40=>"ico_percent_40.png",50=>"ico_percent_50.png",60=>"ico_percent_60.png",70=>"ico_percent_70.png",80=>"ico_percent_80.png",90=>"ico_percent_90.png",100=>"ico_percent_100.png"', '', '', '', 'dpadVivaldiVolume ', '');
-- $VIVALDI_RENDERING_HIGHLOW$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_MIXER', 1, '0', '100', '5', 'ico_audio_generic_on.png', '0=>"_DPAD_DBCONSTANT_RENDERING_0_PERC",10=>"_DPAD_DBCONSTANT_RENDERING_10_PERC",20=>"_DPAD_DBCONSTANT_RENDERING_20_PERC",30=>"_DPAD_DBCONSTANT_RENDERING_30_PERC",40=>"_DPAD_DBCONSTANT_RENDERING_40_PERC",50=>"_DPAD_DBCONSTANT_RENDERING_50_PERC",60=>"_DPAD_DBCONSTANT_RENDERING_60_PERC",70=>"_DPAD_DBCONSTANT_RENDERING_70_PERC",80=>"_DPAD_DBCONSTANT_RENDERING_80_PERC",90=>"_DPAD_DBCONSTANT_RENDERING_90_PERC",100=>"_DPAD_DBCONSTANT_RENDERING_100_PERC', '0=>"ico_percent_0.png",10=>"ico_percent_10.png",20=>"ico_percent_20.png",30=>"ico_percent_30.png",40=>"ico_percent_40.png",50=>"ico_percent_50.png",60=>"ico_percent_60.png",70=>"ico_percent_70.png",80=>"ico_percent_80.png",90=>"ico_percent_90.png",100=>"ico_percent_100.png"', '', '', '', 'dpadVivaldiLow dpadVivaldiHigh ', '');
-- $VIVALDI_RENDERING_CHANNEL$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_CHANNEL', 1, '1', '9', '1', 'ico_number_1.png', '1=>"_DPAD_DBCONSTANT_VIVALDI_CHANNEL_REALNAME_1",2=>"_DPAD_DBCONSTANT_VIVALDI_CHANNEL_REALNAME_2",3=>"_DPAD_DBCONSTANT_VIVALDI_CHANNEL_REALNAME_3",4=>"_DPAD_DBCONSTANT_VIVALDI_CHANNEL_REALNAME_4",5=>"_DPAD_DBCONSTANT_VIVALDI_CHANNEL_REALNAME_5",6=>"_DPAD_DBCONSTANT_VIVALDI_CHANNEL_REALNAME_6",7=>"_DPAD_DBCONSTANT_VIVALDI_CHANNEL_REALNAME_7",8=>"_DPAD_DBCONSTANT_VIVALDI_CHANNEL_REALNAME_8",9=>"_DPAD_DBCONSTANT_VIVALDI_CHANNEL_REALNAME_9"', '1=>"ico_number_1.png",2=>"ico_number_2.png",3=>"ico_number_3.png",4=>"ico_number_4.png",5=>"ico_number_5.png",6=>"ico_number_6.png",7=>"ico_number_7.png",8=>"ico_number_8.png",9=>"ico_number_9.png"', '', '', '', 'dpadVivaldiChannel ', '');
-- $VIVALDI_RENDERING_TUNER$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_TUNER', 0, '87.5', '108.0', '0.5', 'ico_audio_tuner.png', '', '', '', '', '', 'dpadVivaldiTuner ', '');
-- $VIVALDI_RENDERING_CD$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_CD', 0, '1', '99', '1', 'ico_audio_hifi_off.png', '', '', '', '', '', 'dpadVivaldiCd ', '');
-- $VIVALDI_RENDERING_TRACK$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_TRACK', 0, '1', '99', '1', 'ico_audio_hifi_off.png', '', '', '', '', '', 'dpadVivaldiTrack ', '');
-- $VIVALDI_RENDERING_SCENE$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_SCENE', 1, '0', '0', '1', 'ico_scenario_stop.png', '1=>"_DPAD_DBCONSTANT_SCENARIO_STATUS_RUNNING_DESC"', '1=>"ico_scenario_stop.png"', '1=>"button_label_play.png"', '1=>"PLAY"', '', 'dpadVivaldiScene ', '');
-- $VIVALDI_RENDERING_IRCODE_GENERIC$ = INSERT INTO DPADD_RENDERING ( ID, TYPE, TIPOLOGY, NAME, HAS_OPTIONS, MIN_STATE, MAX_STATE, STEP_STATE, IMAGE_PATH, OPTION_LABELS, OPTION_IMAGES, OPTION_SYMBOLS, OPTION_ACTIONS, FORMATTING_SCHEMA, PHPCLASSES, VALUES_TYPE ) VALUES (NULL, NULL, NULL, '_DPAD_DBCONSTANT_RENDERING_VIVALDI_IRCODE', 1, '0', '0', '1', 'ico_infrared_generic.png', '1=>"_DPAD_DBCONSTANT_SCENARIO_STATUS_RUNNING_DESC"', '1=>"ico_infrared_generic.png"', '1=>"button_label_play.png"', '1=>"PLAY"', '', 'dpadVivaldiIrcode ', '');

--INSERT INTO "DPADD_RENDERING_RELATION"(ID,PARENTOBJ_ID,CHILDOBJ_ID,RELATION_CONDITION,OPTIONAL,ORDER_NUM,RELATION_WEB_TIPOLOGY) VALUES(NULL,$VIVALDI_RENDERING_RC20$,$VIVALDI_RENDERING_ONOFF$,'on_off','',1,'GENERIC_RELATION');
--INSERT INTO "DPADD_RENDERING_RELATION"(ID,PARENTOBJ_ID,CHILDOBJ_ID,RELATION_CONDITION,OPTIONAL,ORDER_NUM,RELATION_WEB_TIPOLOGY) VALUES(NULL,$VIVALDI_RENDERING_RC20$,$VIVALDI_RENDERING_VOLUME$,'volume','',2,'GENERIC_RELATION');
--INSERT INTO "DPADD_RENDERING_RELATION"(ID,PARENTOBJ_ID,CHILDOBJ_ID,RELATION_CONDITION,OPTIONAL,ORDER_NUM,RELATION_WEB_TIPOLOGY) VALUES(NULL,$VIVALDI_RENDERING_RC20$,$VIVALDI_RENDERING_HIGHLOW$,'high','',3,'GENERIC_RELATION');
--INSERT INTO "DPADD_RENDERING_RELATION"(ID,PARENTOBJ_ID,CHILDOBJ_ID,RELATION_CONDITION,OPTIONAL,ORDER_NUM,RELATION_WEB_TIPOLOGY) VALUES(NULL,$VIVALDI_RENDERING_RC20$,$VIVALDI_RENDERING_HIGHLOW$,'low','',4,'GENERIC_RELATION');
--INSERT INTO "DPADD_RENDERING_RELATION"(ID,PARENTOBJ_ID,CHILDOBJ_ID,RELATION_CONDITION,OPTIONAL,ORDER_NUM,RELATION_WEB_TIPOLOGY) VALUES(NULL,$VIVALDI_RENDERING_RC20$,$VIVALDI_RENDERING_CHANNEL$,'channel','',5,'GENERIC_RELATION');
--INSERT INTO "DPADD_RENDERING_RELATION"(ID,PARENTOBJ_ID,CHILDOBJ_ID,RELATION_CONDITION,OPTIONAL,ORDER_NUM,RELATION_WEB_TIPOLOGY) VALUES(NULL,$VIVALDI_RENDERING_RC20$,$VIVALDI_RENDERING_TUNER$,'tuner','',6,'GENERIC_RELATION');
--INSERT INTO "DPADD_RENDERING_RELATION"(ID,PARENTOBJ_ID,CHILDOBJ_ID,RELATION_CONDITION,OPTIONAL,ORDER_NUM,RELATION_WEB_TIPOLOGY) VALUES(NULL,$VIVALDI_RENDERING_RC20$,$VIVALDI_RENDERING_CD$,'cd','',7,'GENERIC_RELATION');
--INSERT INTO "DPADD_RENDERING_RELATION"(ID,PARENTOBJ_ID,CHILDOBJ_ID,RELATION_CONDITION,OPTIONAL,ORDER_NUM,RELATION_WEB_TIPOLOGY) VALUES(NULL,$VIVALDI_RENDERING_RC20$,$VIVALDI_RENDERING_TRACK$,'track','',8,'GENERIC_RELATION');

--Vivaldi specific settings
INSERT INTO "DPAD_WEB_TIPOLOGIES" (ID, TIPOLOGY, NAME, DESCRIPTION, IMAGE_PATH) VALUES(NULL, 'vivaldi', '_DPAD_DBCONSTANT_WEBTYPOLOGY_VIVALDI', '_DPAD_DBCONSTANT_WEBTYPOLOGY_VIVALDI', 'vivaldi.png');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES( NULL, 'vivaldi_central_firmware_version', '_DPAD_DBCONSTANT_WEBCONFIGURATION_VIVALDI_CENTRAL_FIRMWARE_VERSION', '1.8', 'vivaldi', 1, '{"1.8":"_DPAD_DBCONSTANT_WEBCONFIGURATION_VIVALDI_FIRMWARE_18","1.9":"_DPAD_DBCONSTANT_WEBCONFIGURATION_VIVALDI_FIRMWARE_18PLUS"}', 'select', -1, NULL );

INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_1', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_1', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_1', 'vivaldi', '0', '', 'textbox', 1,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_2', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_2', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_2', 'vivaldi', '0', '', 'textbox', 2,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_3', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_3', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_3', 'vivaldi', '0', '', 'textbox', 3,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_4', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_4', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_4', 'vivaldi', '0', '', 'textbox', 4,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_5', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_5', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_5', 'vivaldi', '0', '', 'textbox', 5,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_6', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_6', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_6', 'vivaldi', '0', '', 'textbox', 6,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_7', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_7', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_7', 'vivaldi', '0', '', 'textbox', 7,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_8', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_8', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_8', 'vivaldi', '0', '', 'textbox', 8,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_9', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_9', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_9', 'vivaldi', '0', '', 'textbox', 9,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_10', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_10', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_10', 'vivaldi', '0', '', 'textbox', 10,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_11', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_11', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_11', 'vivaldi', '0', '', 'textbox', 11,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_12', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_12', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_12', 'vivaldi', '0', '', 'textbox', 12,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_13', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_13', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_13', 'vivaldi', '0', '', 'textbox', 13,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_14', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_14', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_14', 'vivaldi', '0', '', 'textbox', 14,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_15', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_15', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_15', 'vivaldi', '0', '', 'textbox', 15,'');
INSERT INTO "DPAD_WEB_CONFIGURATION" ( ID, NAME, LABEL, VALUE, TIPOLOGY, HAS_OPTIONS, OPTIONS, DRAW_AS, ORDER_NUM, OPTIONS_EXTERNAL_FUNCTION) VALUES(NULL, 'vivaldi_channel_name_16', '_DPAD_DBCONSTANT_VIVALDI_CHANNEL_LABEL_16', '_DPAD_DBCONSTANT_VIVALDI_DEFAULT_CHANNEL_NAME_16', 'vivaldi', '0', '', 'textbox', 16,'');

--Creating module
INSERT INTO "DPAD_WEB_MODULE" ( ID, NAME, DESCRIPTION, VERSION, IS_ACTIVE, IS_VISIBLE ) VALUES( NULL, "vivaldi", "_DPAD_DBCONSTANT_WEBMODULE_VIVALDI", "3.0.0", 1 , 1);