/*!
jQuery UI Virtual Keyboard
Version 1.17.1

Author: Jeremy Satterfield
Modified: Rob Garrison (Mottie on github)
-----------------------------------------
Licensed under the MIT License

Caret code modified from jquery.caret.1.02.js
Licensed under the MIT License:
http://www.opensource.org/licenses/mit-license.php
-----------------------------------------

An on-screen virtual keyboard embedded within the browser window which
will popup when a specified entry field is focused. The user can then
type and preview their input before Accepting or Canceling.

As a plugin to jQuery UI styling and theme will automatically
match that used by jQuery UI with the exception of the required
CSS listed below.

Requires:
	jQuery
	jQuery UI (position utility only) & CSS

Usage:
	$('input[type=text], input[type=password], textarea')
		.keyboard({
			layout:"qwerty",
			customLayout: {
				'default': [
					"q w e r t y {bksp}",
					"s a m p l e {shift}",
					"{accept} {space} {cancel}"
				],
				'shift' : [
					"Q W E R T Y {bksp}",
					"S A M P L E {shift}",
					"{accept} {space} {cancel}"
				]
			}
		});

Options:
	layout
		[String] specify which keyboard layout to use
		qwerty - Standard QWERTY layout (Default)
		international - US international layout
		alpha  - Alphabetical layout
		dvorak - Dvorak Simplified layout
		num    - Numerical (ten-key) layout
		custom - Uses a custom layout as defined by the customLayout option

	customLayout
		[Object] Specify a custom layout
			An Object containing a set of key:value pairs, each key is a keyset.
			The key can be one to four rows (default, shifted, alt and alt-shift) or any number of meta key sets (meta1, meta2, etc).
			The value is an array with string elements of which each defines a new keyboard row.
			Each string element must have each character or key seperated by a space.
			To include an action key, select the desired one from the list below, or define your own by adding it to the $.keyboard.keyaction variable
			In the list below where two special/"Action" keys are shown, both keys have the same action but different appearances (abbreviated/full name keys).
			Special/"Action" keys include:
				{a}, {accept} - Updates element value and closes keyboard
				{alt},{altgr} - AltGr for International keyboard
				{b}, {bksp}   - Backspace
				{c}, {cancel} - Clears changes and closes keyboard
				{clear}       - Clear input window - used in num pad
				{combo}       - Toggle combo (diacritic) key
				{dec}         - Decimal for numeric entry, only allows one decimal (optional use in num pad)
				{default}     - Switch to the default keyset
				{e}, {enter}  - Return/New Line
				{empty}       - empty (blank) key
				{lock}        - Caps lock key
				{meta#}       - Meta keys that change the key set (# can be any integer)
				{next}        - Switch to next keyboard input/textarea
				{prev}        - Switch to previous keyboard input/textarea
				{s}, {shift}  - Shift
				{sign}        - Change sign of numeric entry (positive or negative)
				{sp:#}        - Replace # with a numerical value, adds blank space, value of 1 ~ width of one key
				{space}       - Spacebar
				{t}, {tab}    - Tab

CSS:
	Please see the keyboard.css file
*//*jshint browser:true, jquery:true, unused:false */(function(a){"use strict";a.keyboard=function(b,c){var d=this,e;d.$el=a(b),d.el=b,d.$el.data("keyboard",d),d.init=function(){d.options=e=a.extend(!0,{},a.keyboard.defaultOptions,c),d.shiftActive=d.altActive=d.metaActive=d.sets=d.capsLock=!1,d.lastKeyset=[!1,!1,!1],d.rows=["","-shift","-alt","-alt-shift"],d.acceptedKeys=[],d.mappedKeys={},a('<!--[if lte IE 8]><script>jQuery("body").addClass("oldie");</script><![endif]--><!--[if IE]><script>jQuery("body").addClass("ie");</script><![endif]-->').appendTo("body").remove(),d.msie=a("body").hasClass("oldie"),d.allie=a("body").hasClass("ie"),d.inPlaceholder=d.$el.attr("placeholder")||"",d.watermark=typeof document.createElement("input").placeholder!="undefined"&&d.inPlaceholder!=="",d.regex=a.keyboard.comboRegex,d.decimal=/^\./.test(e.display.dec)?!0:!1,d.repeatTime=1e3/(e.repeatRate||20),d.temp=a('<input style="position:absolute;left:-9999em;top:-9999em;" type="text" value="testing">').appendTo("body").caret(3,3),d.checkCaret=e.lockInput||d.temp.hide().show().caret().start!==3?!0:!1,d.temp.remove(),d.lastCaret={start:0,end:0},d.temp=["",0,0],a.each("initialized beforeVisible visible change hidden canceled accepted beforeClose".split(" "),function(b,c){a.isFunction(e[c])&&d.$el.bind(c+".keyboard",e[c])}),e.alwaysOpen&&(e.stayOpen=!0),a(document).bind("mousedown.keyboard keyup.keyboard touchstart.keyboard",function(b){if(d.opening)return;d.escClose(b);if(b.target&&a(b.target).hasClass("ui-keyboard-input")){var c=a(b.target).data("keyboard");c&&c.options.openOn&&c.focusOn()}}),d.$el.addClass("ui-keyboard-input "+e.css.input).attr({"aria-haspopup":"true",role:"textbox"}),(d.$el.is(":disabled")||d.$el.attr("readonly")&&!d.$el.hasClass("ui-keyboard-lockedinput"))&&d.$el.addClass("ui-keyboard-nokeyboard"),e.openOn&&d.$el.bind(e.openOn+".keyboard",function(){d.focusOn()}),!d.watermark&&d.$el.val()===""&&d.inPlaceholder!==""&&d.$el.attr("placeholder")!==""&&d.$el.addClass("ui-keyboard-placeholder").val(d.inPlaceholder),d.$el.trigger("initialized.keyboard",[d,d.el]),e.alwaysOpen&&d.reveal()},d.focusOn=function(){d.$el.is(":visible")&&(d.lastCaret=d.$el.caret());if(!d.isVisible()||e.alwaysOpen)clearTimeout(d.timer),d.reveal(),setTimeout(function(){d.$preview.focus()},100)},d.reveal=function(){d.opening=!0,a(".ui-keyboard:not(.ui-keyboard-always-open)").hide();if(d.$el.is(":disabled")||d.$el.attr("readonly")&&!d.$el.hasClass("ui-keyboard-lockedinput")){d.$el.addClass("ui-keyboard-nokeyboard");return}d.$el.removeClass("ui-keyboard-nokeyboard"),e.openOn&&d.$el.unbind(e.openOn+".keyboard"),typeof d.$keyboard=="undefined"&&d.startup(),a(".ui-keyboard-has-focus").removeClass("ui-keyboard-has-focus"),a(".ui-keyboard-input-current").removeClass("ui-keyboard-input-current"),d.$el.addClass("ui-keyboard-input-current"),d.isCurrent(!0),!d.watermark&&d.el.value===d.inPlaceholder&&d.$el.removeClass("ui-keyboard-placeholder").val(""),d.originalContent=d.$el.val(),d.$preview.val(d.originalContent),e.acceptValid&&d.checkValid();var b,c;return d.position=e.position,d.position.of=d.position.of||d.$el.data("keyboardPosition")||d.$el,d.position.collision=e.usePreview?d.position.collision||"fit fit":"flip flip",e.resetDefault&&(d.shiftActive=d.altActive=d.metaActive=!1,d.showKeySet()),d.$keyboard.css({position:"absolute",left:0,top:0}),d.$el.trigger("beforeVisible.keyboard",[d,d.el]),d.$keyboard.addClass("ui-keyboard-has-focus").show(),e.usePreview&&d.msie&&(typeof d.width=="undefined"&&(d.$preview.hide(),d.width=Math.ceil(d.$keyboard.width()),d.$preview.show()),d.$preview.width(d.width)),a.ui.position&&d.$keyboard.position(d.position),d.$preview.focus(),d.checkDecimal(),d.lineHeight=parseInt(d.$preview.css("lineHeight"),10)||parseInt(d.$preview.css("font-size"),10)+4,e.caretToEnd&&(c=d.originalContent.length,d.lastCaret={start:c,end:c}),d.allie&&(c=d.lastCaret.start||d.originalContent.length,b={start:c,end:c},d.lastCaret||(d.lastCaret=b),d.lastCaret.end===0&&d.lastCaret.start>0&&(d.lastCaret.end=d.lastCaret.start),d.lastCaret.start<0&&(d.lastCaret=b)),d.$preview.caret(d.lastCaret.start,d.lastCaret.end),d.$el.trigger("visible.keyboard",[d,d.el]),setTimeout(function(){d.opening=!1,d.$preview.focus()},500),d},d.startup=function(){d.$keyboard=d.buildKeyboard(),d.$allKeys=d.$keyboard.find("button.ui-keyboard-button"),d.preview=d.$preview[0],d.$decBtn=d.$keyboard.find(".ui-keyboard-dec"),d.wheel=a.isFunction(a.fn.mousewheel),d.alwaysAllowed=[20,33,34,35,36,37,38,39,40,45,46],e.enterNavigation&&d.alwaysAllowed.push(13),d.$preview.bind("keypress.keyboard",function(b){var c=d.lastKey=String.fromCharCode(b.charCode||b.which);d.$lastKey=[],d.checkCaret&&(d.lastCaret=d.$preview.caret()),d.capsLock=c>=65&&c<=90&&!b.shiftKey||c>=97&&c<=122&&b.shiftKey?!0:!1;if(e.restrictInput){if(!(b.which!==8&&b.which!==0||!a.inArray(b.keyCode,d.alwaysAllowed)))return;a.inArray(c,d.acceptedKeys)===-1&&b.preventDefault()}else if((b.ctrlKey||b.metaKey)&&(b.which===97||b.which===99||b.which===118||b.which>=120&&b.which<=122))return;d.hasMappedKeys&&d.mappedKeys.hasOwnProperty(c)&&(d.lastKey=d.mappedKeys[c],d.insertText(d.lastKey),b.preventDefault()),d.checkMaxLength()}).bind("keyup.keyboard",function(b){switch(b.which){case 9:d.tab&&e.tabNavigation&&!e.lockInput?(d.shiftActive=b.shiftKey,a.keyboard.keyaction.tab(d),d.tab=!1):b.preventDefault();break;case 27:return d.close(),!1}clearTimeout(d.throttled),d.throttled=setTimeout(function(){d.isVisible()&&d.checkCombos()},100),d.checkMaxLength(),d.$el.trigger("change.keyboard",[d,d.el])}).bind("keydown.keyboard",function(b){switch(b.which){case 9:return e.tabNavigation?(d.tab=!0,!1):(d.tab=!0,!1);case 13:a.keyboard.keyaction.enter(d,null,b);break;case 20:d.shiftActive=d.capsLock=!d.capsLock,d.showKeySet(this);break;case 86:if(b.ctrlKey||b.metaKey){if(e.preventPaste){b.preventDefault();return}d.checkCombos()}}}).bind("mouseup.keyboard touchend.keyboard",function(){d.checkCaret&&(d.lastCaret=d.$preview.caret())}).bind("mousemove.keyboard",function(){d.$preview.focus()}),d.$keyboard.bind("mousedown.keyboard click.keyboard touchstart.keyboard",function(a){a.stopPropagation()}),e.preventPaste&&(d.$preview.bind("contextmenu.keyboard",function(a){a.preventDefault()}),d.$el.bind("contextmenu.keyboard",function(a){a.preventDefault()})),e.appendLocally?d.$el.after(d.$keyboard):d.$keyboard.appendTo("body"),d.$allKeys.bind(e.keyBinding.split(" ").join(".keyboard ")+".keyboard repeater.keyboard",function(b){var c,f=a.data(this,"key"),g=f.action.split(":")[0];d.$preview.focus(),d.$lastKey=a(this),d.lastKey=f.curTxt,d.checkCaret&&d.$preview.caret(d.lastCaret.start,d.lastCaret.end),g.match("meta")&&(g="meta");if(a.keyboard.keyaction.hasOwnProperty(g)&&a(this).hasClass("ui-keyboard-actionkey")){if(a.keyboard.keyaction[g](d,this,b)===!1)return!1}else typeof f.action!="undefined"&&(c=d.lastKey=d.wheel&&!a(this).hasClass("ui-keyboard-actionkey")?f.curTxt:f.action,d.insertText(c),!d.capsLock&&!e.stickyShift&&!b.shiftKey&&(d.shiftActive=!1,d.showKeySet(this)));d.checkCombos(),d.checkMaxLength(),d.$el.trigger("change.keyboard",[d,d.el]),d.$preview.focus(),d.checkCaret&&d.$preview.caret(d.lastCaret.start,d.lastCaret.end),b.preventDefault()}).bind("mouseenter.keyboard mouseleave.keyboard",function(b){var c=this,f=a(this),g=a.data(c,"key");b.type==="mouseenter"&&d.el.type!=="password"&&!f.hasClass(e.css.buttonDisabled)&&f.addClass(e.css.buttonHover).attr("title",function(a,b){return d.wheel&&b===""&&d.sets?e.wheelMessage:b}),b.type==="mouseleave"&&(g.curTxt=g.original,g.curNum=0,a.data(c,"key",g),f.removeClass(d.el.type==="password"?"":e.css.buttonHover).attr("title",function(a,b){return b===e.wheelMessage?"":b}).find("span").text(g.original))}).bind("mousewheel.keyboard",function(b,c){if(d.wheel){var e,f=a(this),g=a.data(this,"key");return e=g.layers||d.getLayers(f),g.curNum+=c>0?-1:1,g.curNum>e.length-1&&(g.curNum=0),g.curNum<0&&(g.curNum=e.length-1),g.layers=e,g.curTxt=e[g.curNum],a.data(this,"key",g),f.find("span").text(e[g.curNum]),!1}}).bind("mouseup.keyboard mouseleave.kb touchend.kb touchmove.kb touchcancel.kb",function(){return d.isVisible()&&d.isCurrent()&&d.$preview.focus(),a(this).removeClass(e.css.buttonHover),d.mouseRepeat=[!1,""],clearTimeout(d.repeater),d.checkCaret&&d.$preview.caret(d.lastCaret.start,d.lastCaret.end),!1}).bind("click.keyboard",function(){return!1}).filter(":not(.ui-keyboard-actionkey)").add(".ui-keyboard-tab, .ui-keyboard-bksp, .ui-keyboard-space, .ui-keyboard-enter",d.$keyboard).bind("mousedown.kb touchstart.kb",function(){if(e.repeatRate!==0){var b=a(this);d.mouseRepeat=[!0,b],setTimeout(function(){d.mouseRepeat[0]&&d.mouseRepeat[1]===b&&d.repeatKey(b)},e.repeatDelay)}return!1}),a(window).resize(function(){d.isVisible()&&d.$keyboard.position(d.position)})},d.isVisible=function(){return typeof d.$keyboard=="undefined"?!1:d.$keyboard.is(":visible")},d.insertText=function(a){var b,c,e,f=d.$preview.val(),g=d.$preview.caret(),h=d.$preview.scrollLeft(),i=d.$preview.scrollTop(),j=f.length;g.end<g.start&&(g.end=g.start),g.start>j&&(g.end=g.start=j),d.preview.tagName==="TEXTAREA"&&(d.msie&&f.substr(g.start,1)==="\n"&&(g.start+=1,g.end+=1),e=f.split("\n").length-1,d.preview.scrollTop=e>0?d.lineHeight*e:i),b=a==="bksp"&&g.start===g.end?!0:!1,a=a==="bksp"?"":a,c=g.start+(b?-1:a.length),h+=parseInt(d.$preview.css("fontSize"),10)*(a==="bksp"?-1:1),d.$preview.val(d.$preview.val().substr(0,g.start-(b?1:0))+a+d.$preview.val().substr(g.end)).caret(c,c).scrollLeft(h),d.checkCaret&&(d.lastCaret={start:c,end:c})},d.checkMaxLength=function(){var a,b=d.$preview.val();e.maxLength!==!1&&b.length>e.maxLength&&(a=Math.min(d.$preview.caret().start,e.maxLength),d.$preview.val(b.substring(0,e.maxLength)),d.$preview.caret(a,a),d.lastCaret={start:a,end:a}),d.$decBtn.length&&d.checkDecimal()},d.repeatKey=function(a){a.trigger("repeater.keyboard"),d.mouseRepeat[0]&&(d.repeater=setTimeout(function(){d.repeatKey(a)},d.repeatTime))},d.showKeySet=function(a){var b="",c=(d.shiftActive?1:0)+(d.altActive?2:0);d.shiftActive||(d.capsLock=!1);if(d.metaActive){b=a&&a.name&&/meta/.test(a.name)?a.name:"",b===""?b=d.metaActive===!0?"":d.metaActive:d.metaActive=b;if(!e.stickyShift&&d.lastKeyset[2]!==d.metaActive||(d.shiftActive||d.altActive)&&!d.$keyboard.find(".ui-keyboard-keyset-"+b+d.rows[c]).length)d.shiftActive=d.altActive=!1}else!e.stickyShift&&d.lastKeyset[2]!==d.metaActive&&d.shiftActive&&(d.shiftActive=d.altActive=!1);c=(d.shiftActive?1:0)+(d.altActive?2:0),b=c===0&&!d.metaActive?"-default":b===""?"":"-"+b;if(!d.$keyboard.find(".ui-keyboard-keyset"+b+d.rows[c]).length){d.shiftActive=d.lastKeyset[0],d.altActive=d.lastKeyset[1],d.metaActive=d.lastKeyset[2];return}d.$keyboard.find(".ui-keyboard-alt, .ui-keyboard-shift, .ui-keyboard-actionkey[class*=meta]").removeClass(e.css.buttonAction).end().find(".ui-keyboard-alt")[d.altActive?"addClass":"removeClass"](e.css.buttonAction).end().find(".ui-keyboard-shift")[d.shiftActive?"addClass":"removeClass"](e.css.buttonAction).end().find(".ui-keyboard-lock")[d.capsLock?"addClass":"removeClass"](e.css.buttonAction).end().find(".ui-keyboard-keyset").hide().end().find(".ui-keyboard-keyset"+b+d.rows[c]).show().end().find(".ui-keyboard-actionkey.ui-keyboard"+b).addClass(e.css.buttonAction),d.lastKeyset=[d.shiftActive,d.altActive,d.metaActive]},d.checkCombos=function(){var a,b,c,f,g=d.$preview.val(),h=d.$preview.caret(),i=g.length;h.end<h.start&&(h.end=h.start),h.start>i&&(h.end=h.start=i),d.msie&&g.substr(h.start,1)==="\n"&&(h.start+=1,h.end+=1),e.useCombos&&(d.msie?g=g.replace(d.regex,function(a,b,c){return e.combos.hasOwnProperty(b)?e.combos[b][c]||a:a}):d.$preview.length&&(c=h.start-(h.start-2>=0?2:0),d.$preview.caret(c,h.end),f=d.$preview.caret().text.replace(d.regex,function(a,b,c){return e.combos.hasOwnProperty(b)?e.combos[b][c]||a:a}),d.$preview.val(d.$preview.caret().replace(f)),g=d.$preview.val()));if(e.restrictInput&&g!==""){c=g,b=d.acceptedKeys.length;for(a=0;a<b;a++){if(c==="")continue;f=d.acceptedKeys[a],g.indexOf(f)>=0&&(/[\[|\]|\\|\^|\$|\.|\||\?|\*|\+|\(|\)|\{|\}]/g.test(f)&&(f="\\"+f),c=c.replace(new RegExp(f,"g"),""))}c!==""&&(g=g.replace(c,""))}return h.start+=g.length-i,h.end+=g.length-i,d.$preview.val(g),d.$preview.caret(h.start,h.end),d.preview.scrollTop=d.lineHeight*(g.substring(0,h.start).split("\n").length-1),d.lastCaret={start:h.start,end:h.end},e.acceptValid&&d.checkValid(),g},d.checkValid=function(){var a=!0;e.validate&&typeof e.validate=="function"&&(a=e.validate(d,d.$preview.val(),!1)),d.$keyboard.find(".ui-keyboard-accept")[a?"removeClass":"addClass"]("ui-keyboard-invalid-input")[a?"addClass":"removeClass"]("ui-keyboard-valid-input")},d.checkDecimal=function(){d.decimal&&/\./g.test(d.preview.value)||!d.decimal&&/\,/g.test(d.preview.value)?d.$decBtn.attr({disabled:"disabled","aria-disabled":"true"}).removeClass(e.css.buttonDefault+" "+e.css.buttonHover).addClass(e.css.buttonDisabled):d.$decBtn.removeAttr("disabled").attr({"aria-disabled":"false"}).addClass(e.css.buttonDefault).removeClass(e.css.buttonDisabled)},d.getLayers=function(b){var c,d;return c=b.attr("data-pos"),d=b.closest(".ui-keyboard").find('button[data-pos="'+c+'"]').map(function(){return a(this).find("> span").text()}).get(),d},d.isCurrent=function(b){var c=a.keyboard.currentKeyboard||!1;return b?c=a.keyboard.currentKeyboard=d.el:b===!1&&c===d.el&&(c=a.keyboard.currentKeyboard=""),c===d.el},d.switchInput=function(b,c){if(typeof e.switchInput=="function")e.switchInput(d,b,c);else{d.$keyboard.hide();var f,g=!1,h=a("button, input, textarea, a").filter(":visible"),i=h.index(d.$el)+(b?1:-1);d.$keyboard.show(),i>h.length-1&&(g=e.stopAtEnd,i=0),i<0&&(g=e.stopAtEnd,i=h.length-1),g||(d.close(c),f=h.eq(i).data("keyboard"),f&&f.options.openOn.length?f.focusOn():h.eq(i).focus())}return!1},d.close=function(b){if(d.isVisible()){clearTimeout(d.throttled);var c=b?d.checkCombos():d.originalContent;if(b&&e.validate&&typeof e.validate=="function"&&!e.validate(d,c,!0)){c=d.originalContent,b=!1;if(e.cancelClose)return}d.isCurrent(!1),d.$el.removeClass("ui-keyboard-input-current ui-keyboard-autoaccepted").addClass(b||!1?b===!0?"":"ui-keyboard-autoaccepted":"").trigger(e.alwaysOpen?"":"beforeClose.keyboard",[d,d.el,b||!1]).val(c).scrollTop(d.el.scrollHeight).trigger(b||!1?"accepted.keyboard":"canceled.keyboard",[d,d.el]).trigger(e.alwaysOpen?"inactive.keyboard":"hidden.keyboard",[d,d.el]).blur(),e.openOn&&(d.timer=setTimeout(function(){d.$el.bind(e.openOn+".keyboard",function(){d.focusOn()}),a(":focus")[0]===d.el&&d.$el.blur()},500)),e.alwaysOpen||d.$keyboard.hide(),!d.watermark&&d.el.value===""&&d.inPlaceholder!==""&&d.$el.addClass("ui-keyboard-placeholder").val(d.inPlaceholder)}return!!b},d.accept=function(){return d.close(!0)},d.escClose=function(a){if(a.type==="keyup")return a.which===27?d.close():"";var b=d.isCurrent();if(!d.isVisible()||e.alwaysOpen&&!b||!e.alwaysOpen&&e.stayOpen&&b&&!d.isVisible())return;a.target!==d.el&&b&&(d.allie&&a.preventDefault(),d.close(e.autoAccept?"true":!1))},d.keyBtn=a("<button />").attr({role:"button","aria-disabled":"false",tabindex:"-1"}).addClass("ui-keyboard-button"),d.addKey=function(b,c,f){var g,h,i,j,k,l=f===!0?b:e.display[c]||b,m=f===!0?b.charCodeAt(0):b;return/\(.+\)/.test(l)&&(j=l.replace(/\(([^()]+)\)/,""),i=l.match(/\(([^()]+)\)/)[1],l=j,k=j.split(":"),j=k[0]!==""&&k.length>1?k[0]:j,d.mappedKeys[i]=j),k=l.split(":"),k[0]===""&&k[1]===""&&(l=":"),l=k[0]!==""&&k.length>1?a.trim(k[0]):l,g=k.length>1?a.trim(k[1]).replace(/_/g," ")||"":"",h=l.length>1?" ui-keyboard-widekey":"",h+=f?"":" ui-keyboard-actionkey",d.keyBtn.clone().attr({"data-value":l,name:m,"data-pos":d.temp[1]+","+d.temp[2],title:g}).data("key",{action:b,original:l,curTxt:l,curNum:0}).addClass("ui-keyboard-"+m+h+" "+e.css.buttonDefault).html("<span>"+l+"</span>").appendTo(d.temp[0])},d.buildKeyboard=function(){var b,c,f,g,h,i,j,k,l=0,m=a("<div />").addClass("ui-keyboard "+e.css.container+(e.alwaysOpen?" ui-keyboard-always-open":"")).attr({role:"textbox"}).hide();e.usePreview?(d.$preview=d.$el.clone(!1).removeAttr("id").removeClass("ui-keyboard-placeholder ui-keyboard-input").addClass("ui-keyboard-preview "+e.css.input).attr("tabindex","-1").show(),a("<div />").addClass("ui-keyboard-preview-wrapper").append(d.$preview).appendTo(m)):(d.$preview=d.$el,e.position.at=e.position.at2),e.lockInput&&d.$preview.addClass("ui-keyboard-lockedinput").attr({readonly:"readonly"});if(e.layout==="custom"||!a.keyboard.layouts.hasOwnProperty(e.layout))e.layout="custom",a.keyboard.layouts.custom=e.customLayout||{"default":["{cancel}"]};return a.each(a.keyboard.layouts[e.layout],function(n,p){if(n!==""){l++,f=a("<div />").attr("name",n).addClass("ui-keyboard-keyset ui-keyboard-keyset-"+n).appendTo(m)[n==="default"?"show":"hide"]();for(c=0;c<p.length;c++){h=a.trim(p[c]).replace(/\{(\.?)[\s+]?:[\s+]?(\.?)\}/g,"{$1:$2}"),j=h.split(/\s+/);for(i=0;i<j.length;i++){d.temp=[f,c,i],g=!1;if(j[i].length===0)continue;if(/^\{\S+\}$/.test(j[i])){b=j[i].match(/^\{(\S+)\}$/)[1].toLowerCase(),/\!\!/.test(b)&&(b=b.replace("!!",""),g=!0),/^sp:((\d+)?([\.|,]\d+)?)(em|px)?$/.test(b)&&(k=parseFloat(b.replace(/,/,".").match(/^sp:((\d+)?([\.|,]\d+)?)(em|px)?$/)[1]||0),a("<span>&nbsp;</span>").width(b.match("px")?k+"px":k*2+"em").addClass("ui-keyboard-button ui-keyboard-spacer").appendTo(f));if(/^meta\d+\:?(\w+)?/.test(b)){d.addKey(b,b);continue}switch(b){case"a":case"accept":d.addKey("accept",b).addClass(e.css.buttonAction);break;case"alt":case"altgr":d.addKey("alt","alt");break;case"b":case"bksp":d.addKey("bksp",b);break;case"c":case"cancel":d.addKey("cancel",b).addClass(e.css.buttonAction);break;case"combo":d.addKey("combo","combo").addClass(e.css.buttonAction);break;case"dec":d.acceptedKeys.push(d.decimal?".":","),d.addKey("dec","dec");break;case"e":case"enter":d.addKey("enter",b).addClass(e.css.buttonAction);break;case"empty":d.addKey(""," ").addClass(e.css.buttonDisabled).attr("aria-disabled",!0);break;case"s":case"shift":d.addKey("shift",b);break;case"sign":d.acceptedKeys.push("-"),d.addKey("sign","sign");break;case"space":d.acceptedKeys.push(" "),d.addKey("space","space");break;case"t":case"tab":d.addKey("tab",b);break;default:a.keyboard.keyaction.hasOwnProperty(b)&&d.addKey(b,b)[g?"addClass":"removeClass"](e.css.buttonAction)}}else d.acceptedKeys.push(j[i].split(":")[0]),d.addKey(j[i],j[i],!0)}f.find(".ui-keyboard-button:last").after('<br class="ui-keyboard-button-endrow">')}}}),l>1&&(d.sets=!0),d.hasMappedKeys=!a.isEmptyObject(d.mappedKeys),m},d.destroy=function(){a(document).unbind("mousedown.keyboard keyup.keyboard touchstart.keyboard"),d.$keyboard&&d.$keyboard.remove();var b=a.trim(e.openOn+" accepted beforeClose canceled change contextmenu hidden initialized keydown keypress keyup visible").split(" ").join(".keyboard ");d.$el.removeClass("ui-keyboard-input ui-keyboard-lockedinput ui-keyboard-placeholder ui-keyboard-notallowed ui-keyboard-always-open "+e.css.input).removeAttr("aria-haspopup").removeAttr("role").unbind(b+".keyboard").removeData("keyboard")},d.init()},a.keyboard.keyaction={accept:function(a){return a.close(!0),!1},alt:function(a,b){a.altActive=!a.altActive,a.showKeySet(b)},bksp:function(a){a.insertText("bksp")},cancel:function(a){return a.close(),!1},clear:function(a){a.$preview.val("")},combo:function(a){var b=!a.options.useCombos;return a.options.useCombos=b,a.$keyboard.find(".ui-keyboard-combo")[b?"addClass":"removeClass"](a.options.css.buttonAction),b&&a.checkCombos(),!1},dec:function(a){a.insertText(a.decimal?".":",")},"default":function(a,b){a.shiftActive=a.altActive=a.metaActive=!1,a.showKeySet(b)},enter:function(b,c,d){var e=b.el.tagName,f=b.options;if(d.shiftKey)return f.enterNavigation?b.switchInput(!d[f.enterMod],!0):b.close(!0);if(f.enterNavigation&&(e!=="TEXTAREA"||d[f.enterMod]))return b.switchInput(!d[f.enterMod],f.autoAccept?"true":!1);e==="TEXTAREA"&&a(d.target).closest("button").length&&b.insertText(" \n")},lock:function(a,b){a.lastKeyset[0]=a.shiftActive=a.capsLock=!a.capsLock,a.showKeySet(b)},meta:function(b,c){b.metaActive=a(c).hasClass(b.options.css.buttonAction)?!1:!0,b.showKeySet(c)},next:function(a){return a.switchInput(!0,a.options.autoAccept),!1},prev:function(a){return a.switchInput(!1,a.options.autoAccept),!1},shift:function(a,b){a.lastKeyset[0]=a.shiftActive=!a.shiftActive,a.showKeySet(b)},sign:function(a){/^\-?\d*\.?\d*$/.test(a.$preview.val())&&a.$preview.val(a.$preview.val()*-1)},space:function(a){a.insertText(" ")},tab:function(a){var b=a.el.tagName,c=a.options;if(b==="INPUT")return c.tabNavigation?a.switchInput(!a.shiftActive,!0):!1;a.insertText("	")}},a.keyboard.layouts={alpha:{"default":["` 1 2 3 4 5 6 7 8 9 0 - = {bksp}","{tab} a b c d e f g h i j [ ] \\","k l m n o p q r s ; ' {enter}","{shift} t u v w x y z , . / {shift}","{accept} {space} {cancel}"],shift:["~ ! @ # $ % ^ & * ( ) _ + {bksp}","{tab} A B C D E F G H I J { } |",'K L M N O P Q R S : " {enter}',"{shift} T U V W X Y Z < > ? {shift}","{accept} {space} {cancel}"]},qwerty:{"default":["` 1 2 3 4 5 6 7 8 9 0 - = {bksp}","{tab} q w e r t y u i o p [ ] \\","a s d f g h j k l ; ' {enter}","{shift} z x c v b n m , . / {shift}","{accept} {space} {cancel}"],shift:["~ ! @ # $ % ^ & * ( ) _ + {bksp}","{tab} Q W E R T Y U I O P { } |",'A S D F G H J K L : " {enter}',"{shift} Z X C V B N M < > ? {shift}","{accept} {space} {cancel}"]},international:{"default":["` 1 2 3 4 5 6 7 8 9 0 - = {bksp}","{tab} q w e r t y u i o p [ ] \\","a s d f g h j k l ; ' {enter}","{shift} z x c v b n m , . / {shift}","{accept} {alt} {space} {alt} {cancel}"],shift:["~ ! @ # $ % ^ & * ( ) _ + {bksp}","{tab} Q W E R T Y U I O P { } |",'A S D F G H J K L : " {enter}',"{shift} Z X C V B N M < > ? {shift}","{accept} {alt} {space} {alt} {cancel}"],alt:["~ ¡ ² ³ ¤ € ¼ ½ ¾ ‘ ’ ¥ × {bksp}","{tab} ä å é ® þ ü ú í ó ö « » ¬","á ß ð f g h j k ø ¶ ´ {enter}","{shift} æ x © v b ñ µ ç > ¿ {shift}","{accept} {alt} {space} {alt} {cancel}"],"alt-shift":["~ ¹ ² ³ £ € ¼ ½ ¾ ‘ ’ ¥ ÷ {bksp}","{tab} Ä Å É ® Þ Ü Ú Í Ó Ö « » ¦","Ä § Ð F G H J K Ø ° ¨ {enter}","{shift} Æ X ¢ V B Ñ µ Ç . ¿ {shift}","{accept} {alt} {space} {alt} {cancel}"]},dvorak:{"default":["` 1 2 3 4 5 6 7 8 9 0 [ ] {bksp}","{tab} ' , . p y f g c r l / = \\","a o e u i d h t n s - {enter}","{shift} ; q j k x b m w v z {shift}","{accept} {space} {cancel}"],shift:["~ ! @ # $ % ^ & * ( ) { } {bksp}",'{tab} " < > P Y F G C R L ? + |',"A O E U I D H T N S _ {enter}","{shift} : Q J K X B M W V Z {shift}","{accept} {space} {cancel}"]},num:{"default":["= ( ) {b}","{clear} / * -","7 8 9 +","4 5 6 {sign}","1 2 3 %","0 . {a} {c}"]}},a.keyboard.defaultOptions={layout:"qwerty",customLayout:null,position:{of:null,my:"center top",at:"center top",at2:"center bottom"},usePreview:!0,alwaysOpen:!1,stayOpen:!1,display:{a:"✔:Accept (Shift-Enter)",accept:"Accept:Accept (Shift-Enter)",alt:"Alt:⌥ AltGr",b:"⌫:Backspace",bksp:"Bksp:Backspace",c:"✖:Cancel (Esc)",cancel:"Cancel:Cancel (Esc)",clear:"C:Clear",combo:"ö:Toggle Combo Keys",dec:".:Decimal",e:"⏎:Enter",empty:" ",enter:"Enter:Enter ⏎",lock:"Lock:⇪ Caps Lock",next:"Next ⇨",prev:"⇦ Prev",s:"⇧:Shift",shift:"Shift:Shift",sign:"±:Change Sign",space:"&nbsp;:Space",t:"⇥:Tab",tab:"⇥ Tab:Tab"},wheelMessage:"Use mousewheel to see other keys",css:{input:"ui-widget-content ui-corner-all",container:"ui-widget-content ui-widget ui-corner-all ui-helper-clearfix",buttonDefault:"ui-state-default ui-corner-all",buttonHover:"ui-state-hover",buttonAction:"ui-state-active",buttonDisabled:"ui-state-disabled"},autoAccept:!1,lockInput:!1,restrictInput:!1,acceptValid:!1,cancelClose:!0,tabNavigation:!1,enterNavigation:!1,enterMod:"altKey",stopAtEnd:!0,appendLocally:!1,stickyShift:!0,preventPaste:!1,caretToEnd:!1,maxLength:!1,repeatDelay:500,repeatRate:20,resetDefault:!1,openOn:"focus",keyBinding:"mousedown touchstart",useCombos:!0,combos:{"`":{a:"à",A:"À",e:"è",E:"È",i:"ì",I:"Ì",o:"ò",O:"Ò",u:"ù",U:"Ù",y:"ỳ",Y:"Ỳ"},"'":{a:"á",A:"Á",e:"é",E:"É",i:"í",I:"Í",o:"ó",O:"Ó",u:"ú",U:"Ú",y:"ý",Y:"Ý"},'"':{a:"ä",A:"Ä",e:"ë",E:"Ë",i:"ï",I:"Ï",o:"ö",O:"Ö",u:"ü",U:"Ü",y:"ÿ",Y:"Ÿ"},"^":{a:"â",A:"Â",e:"ê",E:"Ê",i:"î",I:"Î",o:"ô",O:"Ô",u:"û",U:"Û",y:"ŷ",Y:"Ŷ"},"~":{a:"ã",A:"Ã",e:"ẽ",E:"Ẽ",i:"ĩ",I:"Ĩ",o:"õ",O:"Õ",u:"ũ",U:"Ũ",y:"ỹ",Y:"Ỹ",n:"ñ",N:"Ñ"}},validate:function(a,b,c){return!0}},a.keyboard.comboRegex=/([`\'~\^\"ao])([a-z])/mig,a.keyboard.currentKeyboard="",a.fn.keyboard=function(b){return this.each(function(){a(this).data("keyboard")||new a.keyboard(this,b)})},a.fn.getkeyboard=function(){return this.data("keyboard")}})(jQuery),function(a,b,c,d){"use strict";a.fn.caret=function(a,e){if(typeof this[0]=="undefined"||this.is(":hidden")||this.css("visibility")==="hidden")return this;var f,g,h,i,j,k,l,m,n,o,p=document.selection,q=this[0],r=q.scrollTop,s=typeof q.selectionStart!="undefined";return typeof a=="number"&&typeof e=="number"&&(h=a,j=e),typeof h!="undefined"?(s?(q.selectionStart=h,q.selectionEnd=j):(k=q.createTextRange(),k.collapse(!0),k.moveStart("character",h),k.moveEnd("character",j-h),k.select()),(this.is(":visible")||this.css("visibility")!=="hidden")&&this.focus(),q.scrollTop=r,this):(s?(g=q.selectionStart,i=q.selectionEnd):q.tagName==="TEXTAREA"?(o=this.val(),l=p[c](),m=l[d](),m.moveToElementText(q),m.setEndPoint("EndToEnd",l),g=m.text.replace(/\r/g,"\n")[b],i=g+l.text.replace(/\r/g,"\n")[b]):(o=this.val().replace(/\r/g,"\n"),l=p[c]()[d](),l.moveEnd("character",o[b]),g=l.text===""?o[b]:o.lastIndexOf(l.text),l=p[c]()[d](),l.moveStart("character",-o[b]),i=l.text[b]),n=q.value.substring(g,i),{start:g,end:i,text:n,replace:function(a){return q.value.substring(0,g)+a+q.value.substring(i,q.value[b])}})}}(jQuery,"length","createRange","duplicate");